@@ -28,13 +28,15 @@ from neural_compressor.adaptor.adaptor import adaptor_registry, Adaptor
 from neural_compressor.adaptor.query import QueryBackendCapability
 from neural_compressor.utils.utility import LazyImport, dump_elapsed_time, \
                                             GLOBAL_STATE, MODE
-from ..utils.utility import OpPrecisionStatistics
+from ..utils.utility import Statistics
 from ..experimental.data.dataloaders.base_dataloader import BaseDataLoader
 import math
 
 onnx = LazyImport("onnx")
 ort = LazyImport("onnxruntime")
+ort_ext = LazyImport("onnxruntime_extensions")
 ONNXRT152_VERSION = StrictVersion("1.5.2")
+ONNXRT170_VERSION = StrictVersion("1.7.0")
 
 logger = logging.getLogger()
 
@@ -89,8 +91,13 @@ class ONNXRTAdaptor(Adaptor):
             logger.warning("Quantize input needs model opset 11 or newer.")
         from neural_compressor.adaptor.ox_utils.onnx_quantizer import ONNXQuantizer
         from onnxruntime.quantization.quant_utils import QuantizationMode
-        backend = QuantizationMode.QLinearOps if self.backend == \
-            "qlinearops" else QuantizationMode.IntegerOps
+        if self.backend == "qlinearops":
+            backend = QuantizationMode.QLinearOps
+        elif self.backend == "qdqops":
+            assert ort_version >= ONNXRT170_VERSION, 'QDQ mode needs onnxruntime1.7.0 or newer'
+            backend = self.backend
+        else:
+            backend = QuantizationMode.IntegerOps
 
         self.quantizable_ops = self._query_quantizable_ops(model.model)
         tmp_model = copy.deepcopy(model)
@@ -136,7 +143,12 @@ class ONNXRTAdaptor(Adaptor):
         else:
             quantize_params = None
         self.quantize_params = quantize_params
-        quantizer = ONNXQuantizer(tmp_model.model,
+        if self.backend == "qlinearops" or self.backend == "integerops":
+            quantizer_cls = ONNXQuantizer
+        else:
+            from neural_compressor.adaptor.ox_utils.qdq_quantizer import QDQQuantizer
+            quantizer_cls = QDQQuantizer
+        quantizer = quantizer_cls(tmp_model.model,
             quantize_config,
             backend,
             self.static,
@@ -194,13 +206,23 @@ class ONNXRTAdaptor(Adaptor):
 
         from neural_compressor.adaptor.ox_utils.onnx_quantizer import ONNXQuantizer
         from onnxruntime.quantization.quant_utils import QuantizationMode
-        backend = QuantizationMode.QLinearOps if self.backend == \
-            "qlinearops" else QuantizationMode.IntegerOps
+        if self.backend == "qlinearops":
+            backend = QuantizationMode.QLinearOps
+        elif self.backend == "qdqops":
+            assert ort_version >= ONNXRT170_VERSION, 'QDQ mode needs onnxruntime1.7.0 or newer'
+            backend = self.backend
+        else:
+            backend = QuantizationMode.IntegerOps
 
         self.quantizable_ops = self._query_quantizable_ops(model.model)
         quantize_params, tune_cfg = self._parse_qconfig(q_config)
         quantize_config = self._cfg_to_quantize_config(tune_cfg)
-        quantizer = ONNXQuantizer(model.model,
+        if self.backend == "qlinearops" or self.backend == "integerops":
+            quantizer_cls = ONNXQuantizer
+        else:
+            from neural_compressor.adaptor.ox_utils.qdq_quantizer import QDQQuantizer
+            quantizer_cls = QDQQuantizer
+        quantizer = quantizer_cls(model.model,
             quantize_config,
             backend,
             self.static,
@@ -235,8 +257,14 @@ class ONNXRTAdaptor(Adaptor):
     def _dump_model_op_stats(self, model):
         fp32_op_list = self.query_handler.get_op_types_by_precision( # pylint: disable=no-member
             precision='int8')
+        res = {}
+        for op_type in fp32_op_list:
+            res[op_type] = {'INT8':0, 'BF16': 0, 'FP32':0}
+        for op_type in ["QuantizeLinear", "DequantizeLinear", "DynamicQuantizeLinear"]:
+            res[op_type] = {'INT8':0, 'BF16': 0, 'FP32':0}
 
-        if self.backend == "qlinearops":
+
+        if self.backend in ["qlinearops", "qdqops"] :
             int8_op_list = ["QLinearConv", "QLinearMatMul", "QAttention",
                             "QLinearMul", "QLinearRelu", "QLinearClip",
                             "QLinearLeakyRelu", "QLinearSigmoid", "MaxPool","Squeeze",
@@ -251,17 +279,11 @@ class ONNXRTAdaptor(Adaptor):
                             "DynamicQuantizeLinear"
             ]
 
-        res = {}
-        for op_type in fp32_op_list:
-            res[op_type] = {'INT8':0, 'BF16': 0, 'FP32':0}
-        for op_type in ["QuantizeLinear", "DequantizeLinear", "DynamicQuantizeLinear"]:
-            res[op_type] = {'INT8':0, 'BF16': 0, 'FP32':0}
-
         for node in model.model.graph.node:
             possible_int8_res = [name for name in int8_op_list if node.op_type.find(name) != -1]
-
+ 
             if any(possible_int8_res):
-                if self.backend == "qlinearops":
+                if self.backend in ["qlinearops", 'qdqops']:
                     if node.op_type == "QuantizeLinear" or node.op_type == "DequantizeLinear" \
                             or node.op_type == "DynamicQuantizeLinear":
                         origin_op_type = node.op_type
@@ -272,7 +294,8 @@ class ONNXRTAdaptor(Adaptor):
 
                 if node.op_type in ["Pad", "Split", "Gather", "Concat", "Reshape", "Unsqueeze", 
                     "Squeeze", "Transpose"]:
-                    if any([output.endswith('_quantized') for output in node.output]):
+                    if any([output.endswith('_quantized') for output in node.output]) or \
+                        any(['_DequantizeLinear' in inp for inp in node.input]):
                         origin_op_type = node.op_type
                     else:
                         if node.op_type in res:
@@ -283,12 +306,18 @@ class ONNXRTAdaptor(Adaptor):
                     origin_op_type = "Attention"
                 res[origin_op_type]['INT8'] += 1
 
+            elif node.op_type in fp32_op_list and \
+                any(['_DequantizeLinear' in inp for inp in node.input]):
+                res[node.op_type]['INT8'] += 1
+
             elif node.op_type in fp32_op_list:
                 res[node.op_type]['FP32'] += 1
 
         output_data = [[op_type, sum(res[op_type].values()), res[op_type]['INT8'],
             res[op_type]['BF16'], res[op_type]['FP32']] for op_type in res.keys()]
-        OpPrecisionStatistics(output_data).print_stat()
+        Statistics(output_data, 
+                   header='Mixed Precision Statistics',
+                   field_names=["Op Type", "Total", "INT8", "BF16", "FP32"]).print_stat()
 
     def _get_quantize_params(self, model, data_loader, quantize_config, iterations):
         from neural_compressor.adaptor.ox_utils.onnxrt_mid import ONNXRTAugment
@@ -404,6 +433,7 @@ class ONNXRTAdaptor(Adaptor):
         sess_options.graph_optimization_level = level
         sess_options.optimized_model_filepath = os.path.join(self.work_space, \
             "Optimized_model.onnx")
+        sess_options.register_custom_ops_library(ort_ext.get_library_path())
         _ = ort.InferenceSession(model.model.SerializeToString(), sess_options)
         tmp_model = onnx.load(sess_options.optimized_model_filepath)
         model.model = self._replace_gemm_with_matmul(tmp_model).model \
@@ -578,7 +608,7 @@ class ONNXRTAdaptor(Adaptor):
         return quantizable_op_types
 
     def evaluate(self, input_graph, dataloader, postprocess=None,
-                 metric=None, measurer=None, iteration=-1,
+                 metrics=None, measurer=None, iteration=-1,
                  tensorboard=False, fp32_baseline=False):
         """The function is for evaluation if no given eval func
 
@@ -601,12 +631,17 @@ class ONNXRTAdaptor(Adaptor):
             cores_per_instance = int(os.environ.get('CORES_PER_INSTANCE'))
             assert cores_per_instance > 0, "benchmark cores_per_instance should greater than 0"
             sess_options.intra_op_num_threads = cores_per_instance
-        session = ort.InferenceSession(input_graph.model.SerializeToString(), sess_options)
-        if metric:
-            metric.reset()
-            if hasattr(metric, "compare_label") and not metric.compare_label:
-                self.fp32_preds_as_label = True
-                results = []
+        try:
+            session = ort.InferenceSession(input_graph.model.SerializeToString(), sess_options)
+        except:
+            sess_options.register_custom_ops_library(ort_ext.get_library_path())
+            session = ort.InferenceSession(input_graph.model.SerializeToString(), sess_options)
+        results = []
+        if metrics:
+            for metric in metrics:
+                metric.reset()
+            self.fp32_preds_as_label = any([hasattr(metric, "compare_label") and \
+                not metric.compare_label for metric in metrics]) 
 
         ort_inputs = {}
         len_inputs = len(session.get_inputs())
@@ -647,8 +682,11 @@ class ONNXRTAdaptor(Adaptor):
 
                 if postprocess is not None:
                     predictions, labels = postprocess((predictions, labels))
-                if metric is not None and not self.fp32_preds_as_label:
-                    metric.update(predictions, labels)
+                if metrics:
+                    for metric in metrics:
+                        if not hasattr(metric, "compare_label") or \
+                            (hasattr(metric, "compare_label") and metric.compare_label):
+                            metric.update(predictions, labels)
                 if idx + 1 == iteration:
                     break
 
@@ -668,14 +706,16 @@ class ONNXRTAdaptor(Adaptor):
             from neural_compressor.adaptor.ox_utils.util import collate_preds
             if fp32_baseline:
                 results = collate_preds(self.fp32_results)
-                metric.update(results, results)
+                reference = results
             else:
                 reference = collate_preds(self.fp32_results)
                 results = collate_preds(results)
-                metric.update(results, reference)
+            for metric in metrics:
+                if hasattr(metric, "compare_label") and not metric.compare_label:
+                    metric.update(results, reference)
 
-        acc = metric.result() if metric is not None else 0
-        return acc
+        acc = 0 if metrics is None else [metric.result() for metric in metrics]
+        return acc if not isinstance(acc, list) or len(acc) > 1 else acc[0]
 
     def save(self, model, path):
         """ save model
@@ -716,6 +756,20 @@ class ONNXRT_IntegerOpsAdaptor(ONNXRTAdaptor):
         self.backend = "integerops"
         super().__init__(framework_specific_info)
 
+@adaptor_registry
+class ONNXRT_QDQOpsAdaptor(ONNXRTAdaptor):
+    """The ONNXRT adaptor layer, do onnx-rt quantization, calibration, inspect layer tensors.
+
+    Args:
+        framework_specific_info (dict): framework specific configuration for quantization.
+    """
+
+    def __init__(self, framework_specific_info):
+        self.query_handler = ONNXRTQuery(local_config_file=os.path.join(
+            os.path.dirname(__file__), "onnxrt_qdq.yaml"))
+        self.backend = "qdqops"
+        super().__init__(framework_specific_info)
+
 class ONNXRTQuery(QueryBackendCapability):
 
     def __init__(self, local_config_file=None):
