@@ -154,11 +154,9 @@ class GraphConverter:
                 assert len(input_tensor) == len(inputs), \
                     'inputs len must equal with input_tensor'
                 feed_dict = dict(zip(input_tensor, inputs))
-
-            _ = model.sess.run(output_tensor, feed_dict) if model.iter_op is None \
+            _ = model.sess.run(output_tensor, feed_dict) if model.iter_op==[] \
                 else iterator_sess_run(model.sess, model.iter_op, \
                     feed_dict, output_tensor, self.calib_iteration)
-
             if idx + 1 == self.calib_iteration:
                 break
 
@@ -606,9 +604,10 @@ class GraphConverter:
             self._tmp_graph_def,
             self._tmp_model.input_node_names,
             self._tmp_model.output_node_names)
-
+        
         self._tmp_graph_def, self.quantized_node_info = QuantizeGraphForIntel(
             self._tmp_graph_def,
+            self._tmp_model.input_node_names,
             self._tmp_model.output_node_names,
             self.op_wise_config,
             self.int8_sequences,
@@ -695,14 +694,16 @@ class GraphConverter:
 
             self._tmp_graph_def = FuseMatMulRequantizeDequantizeTransformer(
                 self._tmp_graph_def).do_transformation()
+        
         self._tmp_graph_def = StripUnusedNodesOptimizer(
             self._tmp_graph_def,
             self._tmp_model.input_node_names,
             self._tmp_model.output_node_names).do_transformation()
-
+        
+        input_output_names = self._tmp_model.input_node_names + self._tmp_model.output_node_names
         self._tmp_graph_def = RemoveTrainingNodesOptimizer(
             self._tmp_graph_def,
-            protected_nodes=self._tmp_model.output_node_names).do_transformation()
+            protected_nodes=input_output_names).do_transformation()
 
         self._tmp_graph_def = FoldBatchNormNodesOptimizer(
             self._tmp_graph_def).do_transformation()
