@@ -92,9 +92,20 @@ def _valid_prune_sparsity(key, scope, error):
     elif "target_sparsity" in scope[key]:
         assert scope[key]["target_sparsity"] < 1
 
-def _valid_multi_objective(key, scope, error):
-    if 'weight' in scope and scope['weight'] is not None:
-        assert len(scope['objective']) == len(scope['weight'])
+def _valid_multi_objectives(key, scope, error):
+    if 'weight' in scope[key] and scope[key]['weight'] is not None:
+        assert len(scope[key]['objective']) == len(scope[key]['weight'])
+
+def _valid_multi_metrics(key, scope, error):
+    if 'metric' in scope and 'multi_metrics' in scope:
+        assert False
+
+def _valid_metric_length(key, scope, error):
+    metrics = [i for i in scope[key] if i != 'weight' and i != 'higher_is_better']
+    if 'weight' in scope[key] and scope[key]['weight'] is not None:
+        assert len(input_to_list_float(scope[key]['weight'])) == len(metrics)
+    if 'higher_is_better' in scope[key] and scope[key]['higher_is_better'] is not None:
+        assert len(input_to_list_bool(scope[key]['higher_is_better'])) == len(metrics)
 
 # used for '123.68 116.78 103.94' style to float list
 def input_to_list_float(data):
@@ -107,6 +118,19 @@ def input_to_list_float(data):
     assert isinstance(data, list)
     return [float(d) for d in data]
 
+def input_to_list_bool(data):
+    if isinstance(data, str):
+        if ',' in data:
+            return [s.strip() == 'True' for s in data.split(',')]
+        else:
+            return [s.strip() == 'True' for s in data.split()]
+
+    if isinstance(data, bool):
+        return [data]
+
+    assert isinstance(data, list) and all([isinstance(i, bool) for i in data])
+    return data
+
 def input_int_to_float(data):
     if isinstance(data, str):
         # used for '123.68, 116.78, 103.94' style
@@ -424,6 +448,26 @@ dataset_schema = Schema({
             And(str, Use(input_int_to_float))),
         Optional('dtype'): And(Or(str, list), Use(input_to_list)),
     },
+    Optional('sparse_dummy_v2'): {
+        'dense_shape': And(Or(str, list), Use(list_to_tuple)),
+        Optional('label_shape', default=[1]): And(Or(str, list), Use(list_to_tuple)),
+        Optional('sparse_ratio'): Or(
+            float,
+            And(list, Use(input_int_to_float)),
+            And(int, Use(input_int_to_float))),
+        Optional('low'): Or(
+            float,
+            And(int, Use(input_int_to_float)),
+            And(list, Use(input_int_to_float)),
+            And(str, Use(input_int_to_float))),
+        Optional('high'): Or(
+            float,
+            And(int, Use(input_int_to_float)),
+            And(list, Use(input_int_to_float)),
+            And(str, Use(input_int_to_float))),
+        Optional('dtype'): And(Or(str, list), Use(input_to_list)),
+    },
+ 
     Optional('dummy'): {
         'shape': And(Or(str, list), Use(list_to_tuple)),
         Optional('low'): Or(
@@ -551,6 +595,15 @@ criterion_schema = Schema({
         Optional('temperature'): And(float, lambda s: s > 0),
         Optional('loss_types'): And(list, lambda s: all(i in ['CE', 'KL'] for i in s)),
         Optional('loss_weights'): And(list, lambda s: all(i >= 0 for i in s) and sum(s) == 1.0),
+    },
+    Optional('IntermediateLayersKnowledgeDistillationLoss'): {
+        'layer_mappings':
+            And(Or(tuple, list), lambda s: all(len(i) in [2, 4] for i in s)),
+        Optional('loss_types'):
+            And(Or(tuple, list), lambda s: all(i in ['MSE', 'KL', 'L1'] for i in s)),
+        Optional('loss_weights'):
+            And(Or(tuple, list), lambda s: all(i >= 0 for i in s) and sum(s) == 1.0),
+        Optional('add_origin_loss'): bool,
     }
 })
 
@@ -708,7 +761,7 @@ schema = Schema({
     Optional('tuning', default={
         'strategy': {'name': 'basic'},
         'accuracy_criterion': {'relative': 0.01, 'higher_is_better': True},
-        'multi_objective': {'objective': ['performance']},
+        'objective': 'performance',
         'exit_policy': {'timeout': 0, 'max_trials': 100, 'performance_only': False},
         'random_seed': 1978, 'tensorboard': False,
         'workspace': {'path': default_workspace}}): {
@@ -725,11 +778,14 @@ schema = Schema({
             Optional('absolute'): And(Or(str, int, float), Use(percent_to_float)),
             Optional('higher_is_better', default=True): bool,
         },
-        Hook('multi_objective', handler=_valid_multi_objective): object,
-        Optional('multi_objective', default={'objective': ['performance']}): {
-            Optional('objective', default=['performance']): And(
+        Optional('objective', default='performance'): And(str, lambda s: s in OBJECTIVES),
+        Hook('multi_objectives', handler=_valid_multi_objectives): object,
+        Optional('multi_objectives'):{ 
+            Optional('objective'): And(
                 Or(str, list), Use(input_to_list), lambda s: all(i in OBJECTIVES for i in s)),
-            Optional('weight', default=None): And(Or(str, list), Use(input_to_list_float)),
+            Optional('weight'): And(Or(str, list), Use(input_to_list_float)),
+            Optional('higher_is_better'): And(
+                Or(str, bool, list), Use(input_to_list_bool)),
         },
         Optional('exit_policy', default={'timeout': 0,
                                          'max_trials': 100,
@@ -746,7 +802,61 @@ schema = Schema({
         }
     },
     Optional('evaluation'): {
+        Hook('accuracy', handler=_valid_multi_metrics): object,
         Optional('accuracy'): {
+            Hook('multi_metrics', handler=_valid_metric_length): object,
+            Optional('multi_metrics', default=None): {
+                Optional('weight'): And(Or(str, list), Use(input_to_list_float)),
+                Optional('higher_is_better'): And(
+                    Or(str, list), Use(input_to_list_bool)),
+                Optional('topk'): And(int, lambda s: s in [1, 5]),
+                Optional('mAP'): {
+                    Optional('anno_path'): str,
+                    Optional('iou_thrs', default=0.5):
+                            Or(And(str, lambda s: s in ['0.5:0.05:0.95']),
+                               And(float, lambda s: s <= 1.0 and s >= 0.0)),
+                    Optional('map_points', default=0): And(int, lambda s: s in [0, 11, 101])
+                },
+                Optional('COCOmAP'): {
+                    Optional('anno_path'): str,
+                    Optional('map_key', default='DetectionBoxes_Precision/mAP'): str
+                },
+                Optional('COCOmAPv2'): {
+                    Optional('anno_path'): str,
+                    Optional('map_key', default='DetectionBoxes_Precision/mAP'): str,
+                    Optional('output_index_mapping', default={'num_detections': -1, 
+                                                      'boxes': 0, 
+                                                      'scores': 1, 
+                                                      'classes': 2}): COCOmAP_input_order_schema
+                },
+                Optional('VOCmAP'): {
+                    Optional('anno_path'): str
+                },
+                Optional('SquadF1'): Or({}, None),
+                Optional('MSE'): {
+                    Optional('compare_label'): bool
+                },
+                Optional('RMSE'): {
+                    Optional('compare_label'): bool
+                },
+                Optional('MAE'): {
+                    Optional('compare_label'): bool
+                },
+                Optional('Accuracy'): Or({}, None),
+                Optional('Loss'): Or({}, None),
+                Optional('BLEU'): Or({}, None),
+                Optional('SquadF1'): Or({}, None),
+                Optional('F1'): Or({}, None),
+                Optional('mIOU'): {
+                    Optional('num_classes'): int
+                },
+                Optional('GLUE'): {
+                    Optional('task'): str
+                },
+                Optional('ROC'): {
+                    Optional('task'): str
+                },
+            }, 
             Optional('metric', default=None): {
                 Optional('topk'): And(int, lambda s: s in [1, 5]),
                 Optional('mAP'): {
@@ -823,6 +933,35 @@ schema = Schema({
         Optional("train"): train_schema
     },
 
+    Optional('auto_distillation'): {
+        "search": {
+            "search_space": dict,
+            Optional("search_algorithm", default=""): str,
+            Optional("metrics", default=[]): list,
+            Optional("higher_is_better", default=[]): list,
+            Optional("max_trials", default=1): int,
+            Optional("seed", default=42): int,
+            },
+        Optional("flash_distillation"): {
+            Optional("knowledge_transfer"): {
+                Optional("block_names", default=[]): list,
+                "layer_mappings_for_knowledge_transfer": list,
+                Optional("loss_types", default=[]): list,
+                Optional("loss_weights", default=[]): list,
+                Optional("add_origin_loss", default=[]): list,
+                Optional("train_steps", default=[]): list,
+                },
+            Optional("regular_distillation"): {
+                Optional("block_names", default=[]): list,
+                "layer_mappings_for_knowledge_transfer": list,
+                Optional("loss_types", default=[]): list,
+                Optional("loss_weights", default=[]): list,
+                Optional("add_origin_loss", default=[]): list,
+                Optional("train_steps", default=[]): list,
+                },
+            },
+    },
+
     Optional("train"): train_schema
 })
 
@@ -841,12 +980,13 @@ quantization_default_schema = Schema({
                                                       'scale_propagation_concat': True,
                                                       'first_conv_or_matmul_quantization': True},
                                       'model_wise': {'weight': {'bit': [7.0]},
-                                                     'activation': {}}}): dict,
+                                                     'activation': {}},
+                                        'dtype':'int8'}): dict,
 
     Optional('tuning', default={
         'strategy': {'name': 'basic'},
         'accuracy_criterion': {'relative': 0.01, 'higher_is_better': True},
-        'multi_objective': {'objective': ['performance']},
+        'objective': 'performance',
         'exit_policy': {'timeout': 0, 'max_trials': 100, 'performance_only': False},
         'random_seed': 1978, 'tensorboard': False,
         'workspace': {'path': default_workspace}}): dict,
@@ -894,7 +1034,7 @@ graph_optimization_default_schema = Schema({
     Optional('tuning', default={
         'strategy': {'name': 'basic'},
         'accuracy_criterion': {'relative': 0.01, 'higher_is_better': True},
-        'multi_objective': {'objective': ['performance']},
+        'objective': 'performance',
         'exit_policy': {'timeout': 0, 'max_trials': 100, 'performance_only': False},
         'random_seed': 1978, 'tensorboard': False,
         'workspace': {'path': default_workspace}}): dict,
@@ -924,7 +1064,7 @@ benchmark_default_schema = Schema({
     Optional('tuning', default={
         'strategy': {'name': 'basic'},
         'accuracy_criterion': {'relative': 0.01, 'higher_is_better': True},
-        'multi_objective': {'objective': ['performance']},
+        'objective': 'performance',
         'exit_policy': {'timeout': 0, 'max_trials': 100, 'performance_only': False},
         'random_seed': 1978, 'tensorboard': False,
         'workspace': {'path': default_workspace}}): dict,
@@ -1025,9 +1165,11 @@ class Conf(object):
                         'criterion', 'optimizer']:
                         # accuracy_criterion can only have one of absolute and relative
                         # others can only have one item
-                        inter_key = src[key].keys() & dst[key].keys() - 'higher_is_better'
+                        inter_key = src[key].keys() & dst[key].keys()-{'higher_is_better'}
                         if len(inter_key) == 0:
                             dst[key] = {}
+                    if key == 'accuracy' and src[key].get('multi_metrics', None):
+                        dst[key].pop('metric', None)
                     self._convert_cfg(src[key], dst[key])
                 elif dst[key] == src[key]:
                     pass  # same leaf value
