@@ -187,8 +187,8 @@ class BilinearImagenetTransform(BaseTransform):
 
         return (image, label)
 
-@transform_registry(transform_type="BilinearImagenet", \
-                    process="preprocess", framework="onnxrt_qlinearops, onnxrt_integerops")
+@transform_registry(transform_type="BilinearImagenet", process="preprocess", \
+                    framework="onnxrt_qlinearops, onnxrt_integerops, onnxrt_qdqops")
 class OnnxBilinearImagenetTransform(BaseTransform):
     """Combination of a series of transforms which is applicable to images in Imagenet.
 
@@ -238,8 +238,8 @@ class OnnxBilinearImagenetTransform(BaseTransform):
 
         return (image, label)
 
-@transform_registry(transform_type="ResizeCropImagenet", \
-                    process="preprocess", framework="onnxrt_qlinearops, onnxrt_integerops")
+@transform_registry(transform_type="ResizeCropImagenet", process="preprocess", \
+                    framework="onnxrt_qlinearops, onnxrt_integerops, onnxrt_qdqops")
 class ONNXResizeCropImagenetTransform(BaseTransform):
     """Combination of a series of transforms which is applicable to images in Imagenet.
 
@@ -293,8 +293,8 @@ class ONNXResizeCropImagenetTransform(BaseTransform):
         image = ((image - self.mean_value)/self.std_value).astype(np.float32)
         return (image.transpose(2, 0, 1), label)
 
-@transform_registry(transform_type="ResizeWithAspectRatio", \
-                    process="preprocess", framework="onnxrt_qlinearops, onnxrt_integerops")
+@transform_registry(transform_type="ResizeWithAspectRatio", process="preprocess", \
+                    framework="onnxrt_qlinearops, onnxrt_integerops, onnxrt_qdqops")
 class ResizeWithAspectRatio(BaseTransform):
     def __init__(self, height, width, scale=87.5, inter_pol=cv2.INTER_AREA):
         self.height = height
