@@ -200,7 +200,7 @@ class Benchmark(object):
         iteration = -1 if deep_get(cfg, 'evaluation.{}.iteration'.format(mode)) is None \
             else deep_get(cfg, 'evaluation.{}.iteration'.format(mode))
 
-        metric = self._metric if self._metric else \
+        metric = [self._metric] if self._metric else \
                     deep_get(cfg, 'evaluation.{}.metric'.format(mode))
         b_postprocess_cfg = deep_get(cfg, 'evaluation.{}.postprocess'.format(mode))
 
@@ -224,15 +224,14 @@ class Benchmark(object):
                                       b_postprocess_cfg,
                                       iteration=iteration)
 
-        objectives = [i.lower() for i in cfg.tuning.multi_objective.objective]
+        objectives = [i.lower() for i in cfg.tuning.multi_objectives.objective] if \
+            deep_get(cfg, 'tuning.multi_objectives') else [cfg.tuning.objective]
         assert len(objectives) == 1, 'benchmark supports one objective at a time'
-        self.multi_objective = MultiObjective(objectives,
-                                              cfg.tuning.accuracy_criterion,
-                                              cfg.tuning.multi_objective.weight,
-                                              is_measure=True)
+        self.objectives = MultiObjective(objectives,
+                              cfg.tuning.accuracy_criterion,
+                              is_measure=True)
 
-
-        val = self.multi_objective.evaluate(b_func, self._model)
+        val = self.objectives.evaluate(b_func, self._model)
         # measurer contain info not only performance(eg, memory, model_size)
         # also measurer have result list among steps
         acc, _ = val
@@ -240,13 +239,13 @@ class Benchmark(object):
         warmup =  0 if deep_get(cfg, 'evaluation.{}.warmup'.format(mode)) is None \
             else deep_get(cfg, 'evaluation.{}.warmup'.format(mode))
 
-        if len(self.multi_objective.objectives[0].result_list()) < warmup:
-            if len(self.multi_objective.objectives[0].result_list()) > 1 and warmup != 0:
+        if len(self.objectives.objectives[0].result_list()) < warmup:
+            if len(self.objectives.objectives[0].result_list()) > 1 and warmup != 0:
                 warmup = 1
             else:
                 warmup = 0
 
-        result_list = self.multi_objective.objectives[0].result_list()[warmup:]
+        result_list = self.objectives.objectives[0].result_list()[warmup:]
         latency = np.array(result_list).mean() / batch_size
         self._results[mode] = acc, batch_size, result_list
 
@@ -255,7 +254,10 @@ class Benchmark(object):
             logger.debug("Iteration {} result {}:".format(i, res))
         if mode == 'accuracy':
             logger.info("Batch size = {}".format(batch_size))
-            logger.info("Accuracy is {:.4f}".format(acc))
+            if isinstance(acc, list):
+                logger.info("Accuracy is" + "".join([" {:.4f}".format(i) for i in acc]))
+            else:
+                logger.info("Accuracy is {:.4f}".format(acc))
         elif mode == 'performance':
             logger.info("Batch size = {}".format(batch_size))
             logger.info("Latency: {:.3f} ms".format(latency * 1000))
