@@ -65,6 +65,12 @@ class ONNXRTITDatasets(object):
         self.datasets = {}
         self.datasets.update(ONNXRTIT_DATASETS)
 
+@singleton
+class ONNXRTQDQDatasets(object):
+    def __init__(self):
+        self.datasets = {}
+        self.datasets.update(ONNXRTQDQ_DATASETS)
+
 class PytorchMxnetWrapDataset():
     def __init__(self, datafunc):
         self.datafunc = datafunc
@@ -100,6 +106,7 @@ framework_datasets = {"tensorflow": TensorflowDatasets,
                       "pytorch": PyTorchDatasets,
                       "pytorch_ipex": PyTorchDatasets,
                       "pytorch_fx": PyTorchDatasets,
+                      "onnxrt_qdqops": ONNXRTQDQDatasets,
                       "onnxrt_qlinearops": ONNXRTQLDatasets,
                       "onnxrt_integerops": ONNXRTITDatasets,
                       "engine": EngineDatasets}
@@ -117,7 +124,7 @@ framework_datasets = {"tensorflow": TensorflowDatasets,
 
 class DATASETS(object):
     def __init__(self, framework):
-        assert framework in ["tensorflow", "tensorflow_itex",
+        assert framework in ["tensorflow", "tensorflow_itex", "onnxrt_qdqops",
                              "mxnet", "onnxrt_qlinearops", "onnxrt_integerops",
                              "pytorch", "pytorch_ipex", "pytorch_fx", "engine"], \
                              "framework support tensorflow pytorch mxnet onnxrt engine"
@@ -137,15 +144,17 @@ PYTORCHIPEX_DATASETS = {}
 PYTORCHFX_DATASETS = {}
 ONNXRTQL_DATASETS = {}
 ONNXRTIT_DATASETS = {}
+ONNXRTQDQ_DATASETS = {}
 ENGINE_DATASETS = {}
 
 registry_datasets = {"tensorflow": TENSORFLOW_DATASETS,
-                    "tensorflow_itex": TENSORFLOWITEX_DATASETS,
+                     "tensorflow_itex": TENSORFLOWITEX_DATASETS,
                      "mxnet": MXNET_DATASETS,
                      "pytorch": PYTORCH_DATASETS,
                      "pytorch_ipex": PYTORCHIPEX_DATASETS,
                      "pytorch_fx": PYTORCHFX_DATASETS,
                      "onnxrt_integerops": ONNXRTQL_DATASETS,
+                     "onnxrt_qdqops": ONNXRTQDQ_DATASETS,
                      "onnxrt_qlinearops": ONNXRTIT_DATASETS,
                      "engine": ENGINE_DATASETS}
 
@@ -174,6 +183,7 @@ def dataset_registry(dataset_type, framework, dataset_format=''):
                 "pytorch_fx",
                 "onnxrt_qlinearops",
                 "onnxrt_integerops",
+                "onnxrt_qdqops",
                 "engine"
             ], "The framework support tensorflow mxnet pytorch onnxrt engine"
             dataset_name = dataset_type + dataset_format
@@ -266,7 +276,7 @@ def calculate_md5(fpath, chunk_size=1024*1024):
     return md5.hexdigest()
 
 @dataset_registry(dataset_type="CIFAR10", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+                    onnxrt_integerops, onnxrt_qdqops", dataset_format='')
 class CIFAR10(Dataset):
     """Configuration for CIFAR10 and CIFAR100 database
 
@@ -414,7 +424,7 @@ class TensorflowCIFAR10(CIFAR10):
         return (image, label)
 
 @dataset_registry(dataset_type="CIFAR100", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+                    onnxrt_integerops, onnxrt_qdqops", dataset_format='')
 class CIFAR100(CIFAR10):
     url = "https://www.cs.toronto.edu/~kriz/cifar-100-python.tar.gz"
     filename = "cifar-100-python.tar.gz"
@@ -464,7 +474,7 @@ class TensorflowCIFAR100(CIFAR100):
         return (image, label)
 
 @dataset_registry(dataset_type="MNIST", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+                    onnxrt_integerops, onnxrt_qdqops", dataset_format='')
 class MNIST(Dataset):
     """Configuration for Modified National Institute of Standards and Technology database
        and FashionMNIST database
@@ -573,7 +583,7 @@ class TensorflowMNIST(MNIST):
         return (image, label)
 
 @dataset_registry(dataset_type="FashionMNIST", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+                    onnxrt_qdqops, onnxrt_integerops", dataset_format='')
 class FashionMNIST(MNIST):
     resource = [
         ('https://storage.googleapis.com/tensorflow/tf-keras-datasets/' + file_name, None)
@@ -637,7 +647,7 @@ class TensorflowFashionMNIST(FashionMNIST):
         return (image, label)
 
 @dataset_registry(dataset_type="ImageFolder", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+                    onnxrt_qdqops, onnxrt_integerops", dataset_format='')
 class ImageFolder(Dataset):
     """Configuration for ImageFolder
 
