@@ -28,7 +28,7 @@ logger = logging.getLogger()
 @dataset_registry(dataset_type="dummy", framework="tensorflow, tensorflow_itex, \
                                                     onnxrt_qlinearops, onnxrt_integerops, \
                                                     pytorch, pytorch_ipex, pytorch_fx, \
-                                                    mxnet, engine",
+                                                    mxnet, engine, onnxrt_qdqops",
                                                     dataset_format='')
 class DummyDataset(Dataset):
     """Dataset used for dummy data generation.
@@ -54,8 +54,7 @@ class DummyDataset(Dataset):
                                                         If transform is not None, it will ignore
                                                         it.  
           filter (Filter objects, default=None): filter out examples according to 
-                                                specific conditions
-
+                                                specific conditions                                         
     """
     def __init__(self, shape, low=-128., high=127., dtype='float32', label=True, \
         transform=None, filter=None):
@@ -66,7 +65,9 @@ class DummyDataset(Dataset):
         np.random.seed(9527)
         self.transform = transform
         self.label = label
-        if isinstance(shape, list):
+        if len(shape)==0:
+            logger.info("No data in the dummy dataset.")
+        elif isinstance(shape, list):
             # list tensor should same first demension n
             n = shape[0][0]
             assert all(isinstance(elem, tuple) and elem[0] == n for elem in shape), \
