@@ -170,6 +170,22 @@ class ONNXRTITTransforms(Transforms):
         general.update(ONNXRT_IT_TRANSFORMS["general"])
         return general
 
+class ONNXRTQDQTransforms(Transforms):
+    def _get_preprocess(self):
+        preprocess = {}
+        preprocess.update(ONNXRT_QDQ_TRANSFORMS["preprocess"])
+        return preprocess
+
+    def _get_postprocess(self):
+        postprocess = {}
+        postprocess.update(ONNXRT_QDQ_TRANSFORMS["postprocess"])
+        return postprocess
+
+    def _get_general(self):
+        general = {}
+        general.update(ONNXRT_QDQ_TRANSFORMS["general"])
+        return general
+
 class EngineTransforms(Transforms):
     def _get_preprocess(self):
         preprocess = {}
@@ -194,6 +210,7 @@ framework_transforms = {"tensorflow": TensorflowTransforms,
                         "pytorch_fx": PyTorchTransforms,
                         "onnxrt_qlinearops": ONNXRTQLTransforms,
                         "onnxrt_integerops": ONNXRTITTransforms,
+                        "onnxrt_qdqops": ONNXRTQDQTransforms,
                         "engine": EngineTransforms}
 
 # transform registry will register transforms into these dicts
@@ -201,6 +218,7 @@ TENSORFLOW_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 MXNET_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 PYTORCH_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 ONNXRT_QL_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
+ONNXRT_QDQ_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 ONNXRT_IT_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 ENGINE_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 
@@ -211,13 +229,14 @@ registry_transforms = {"tensorflow": TENSORFLOW_TRANSFORMS,
                        "pytorch_ipex": PYTORCH_TRANSFORMS,
                        "pytorch_fx": PYTORCH_TRANSFORMS,
                        "onnxrt_qlinearops": ONNXRT_QL_TRANSFORMS,
+                       "onnxrt_qdqops": ONNXRT_QDQ_TRANSFORMS,
                        "onnxrt_integerops": ONNXRT_IT_TRANSFORMS,
                        "engine": ENGINE_TRANSFORMS}
 
 class TRANSFORMS(object):
     def __init__(self, framework, process):
         assert framework in ("tensorflow", "tensorflow_itex", "engine",
-                             "pytorch", "pytorch_ipex", "pytorch_fx",
+                             "pytorch", "pytorch_ipex", "pytorch_fx", "onnxrt_qdqops",
                              "onnxrt_qlinearops", "onnxrt_integerops", "mxnet"), \
                              "framework support tensorflow pytorch mxnet onnxrt engine"
         assert process in ("preprocess", "postprocess",
@@ -260,6 +279,7 @@ def transform_registry(transform_type, process, framework):
                 "pytorch_ipex",
                 "pytorch_fx",
                 "onnxrt_qlinearops",
+                "onnxrt_qdqops",
                 "onnxrt_integerops",
                 "engine"
             ], "The framework support tensorflow mxnet pytorch onnxrt engine"
@@ -343,7 +363,8 @@ def get_torchvision_map(interpolation):
         return interpolation
 
 @transform_registry(transform_type="Compose", process="general", \
-                 framework="onnxrt_qlinearops, onnxrt_integerops, tensorflow, engine")
+                 framework="onnxrt_qlinearops, onnxrt_integerops, tensorflow, \
+                            engine, onnxrt_qdqops")
 class ComposeTransform(BaseTransform):
     """Composes several transforms together.
 
@@ -419,7 +440,7 @@ class MXNetCropToBoundingBox(CropToBoundingBox):
         return (image, label)
 
 @transform_registry(transform_type="CropToBoundingBox", process="preprocess", \
-                framework="onnxrt_qlinearops, onnxrt_integerops")
+                framework="onnxrt_qdqops, onnxrt_qlinearops, onnxrt_integerops")
 class ONNXRTCropToBoundingBox(CropToBoundingBox):
     """Crops an image to a specified bounding box.
 
@@ -465,7 +486,7 @@ class TensorflowCropToBoundingBox(CropToBoundingBox):
         return (image, label)
 
 @transform_registry(transform_type="ResizeWithRatio", process="preprocess", \
-                framework="onnxrt_qlinearops, onnxrt_integerops, pytorch, mxnet")
+                framework="onnxrt_qdqops, onnxrt_qlinearops, onnxrt_integerops, pytorch, mxnet")
 class ResizeWithRatio(BaseTransform):
     """Resize image with aspect ratio and pad it to max shape(optional).
        If the image is padded, the label will be processed at the same time.
@@ -580,7 +601,7 @@ class TensorflowResizeWithRatio(BaseTransform):
         return image, (bbox, str_label, int_label, image_id)
 
 @transform_registry(transform_type="Transpose", process="preprocess", \
-        framework="onnxrt_qlinearops, onnxrt_integerops")
+        framework="onnxrt_qlinearops, onnxrt_integerops, onnxrt_qdqops")
 class Transpose(BaseTransform):
     """Transpose image according to perm.
 
@@ -655,7 +676,7 @@ class PyTorchTranspose(Transpose):
         return (image, label)
 
 @transform_registry(transform_type="RandomVerticalFlip", process="preprocess", \
-        framework="onnxrt_qlinearops, onnxrt_integerops")
+        framework="onnxrt_qdqops, onnxrt_qlinearops, onnxrt_integerops")
 class RandomVerticalFlip(BaseTransform):
     """Vertically flip the given image randomly.
 
@@ -688,7 +709,7 @@ class TensorflowRandomVerticalFlip(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="RandomHorizontalFlip", process="preprocess", \
-        framework="onnxrt_qlinearops, onnxrt_integerops")
+        framework="onnxrt_qdqops, onnxrt_qlinearops, onnxrt_integerops")
 class RandomHorizontalFlip(BaseTransform):
     """Horizontally flip the given image randomly.
 
@@ -721,7 +742,8 @@ class TensorflowRandomHorizontalFlip(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="ToArray", process="preprocess", \
-        framework="onnxrt_qlinearops, onnxrt_integerops, tensorflow, pytorch, mxnet")
+        framework="onnxrt_qdqops, onnxrt_qlinearops, onnxrt_integerops, \
+                   tensorflow, pytorch, mxnet")
 class ToArray(BaseTransform):
     """Convert PIL Image or NDArray to numpy array.
 
@@ -776,8 +798,8 @@ class CastTFTransform(BaseTransform):
             image = image.astype(np_dtype_map[self.dtype])
         return (image, label)
 
-@transform_registry(transform_type="Cast",
-                    process="general", framework="onnxrt_qlinearops, onnxrt_integerops")
+@transform_registry(transform_type="Cast", process="general",
+                    framework="onnxrt_qlinearops, onnxrt_integerops, onnxrt_qdqops")
 class CastONNXTransform(BaseTransform):
     """Convert image to given dtype.
 
@@ -1263,7 +1285,7 @@ class RescaleTFTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type='Rescale', process="preprocess", \
-                framework='onnxrt_qlinearops, onnxrt_integerops')
+                framework='onnxrt_qlinearops, onnxrt_integerops, onnxrt_qdqops')
 class RescaleTransform(BaseTransform):
     """Scale the values of image to [0,1].
 
@@ -1278,7 +1300,8 @@ class RescaleTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type='AlignImageChannel', process="preprocess", \
-    framework='tensorflow, onnxrt_qlinearops, onnxrt_integerops, mxnet')
+    framework='tensorflow, onnxrt_qlinearops, onnxrt_integerops, mxnet, \
+               onnxrt_qdqops')
 class AlignImageChannelTransform(BaseTransform):
     """ Align image channel, now just support [H,W]->[H,W,dim], [H,W,4]->[H,W,3] and
         [H,W,3]->[H,W].
@@ -1386,7 +1409,7 @@ class ResizeMXNetTransform(BaseTransform):
 
 
 @transform_registry(transform_type="Resize", process="preprocess", \
-                framework="onnxrt_qlinearops, onnxrt_integerops")
+                framework="onnxrt_qlinearops, onnxrt_integerops, onnxrt_qdqops")
 class ResizeTransform(BaseTransform):
     """Resize the input image to the given size.
 
@@ -1536,7 +1559,7 @@ class MXNetCropResizeTransform(BaseTransform):
         return (transformer(image), label)
 
 @transform_registry(transform_type="CropResize", process="preprocess", \
-                framework="onnxrt_qlinearops, onnxrt_integerops")
+                framework="onnxrt_qdqops, onnxrt_qlinearops, onnxrt_integerops")
 class CropResizeTransform(BaseTransform):
     """Crop the input image with given location and resize it.
 
@@ -1577,7 +1600,7 @@ class CropResizeTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="CenterCrop", process="preprocess", \
-                framework="onnxrt_qlinearops, onnxrt_integerops")
+                framework="onnxrt_qlinearops, onnxrt_integerops, onnxrt_qdqops")
 class CenterCropTransform(BaseTransform):
     """Crops the given image at the center to the given size.
 
@@ -1672,7 +1695,7 @@ class PyTorchNormalizeTransform(MXNetNormalizeTransform):
         return (image, label)
 
 @transform_registry(transform_type="Normalize", process="preprocess", \
-                framework="onnxrt_qlinearops, onnxrt_integerops")
+                framework="onnxrt_qlinearops, onnxrt_integerops, onnxrt_qdqops")
 class NormalizeTransform(BaseTransform):
     """Normalize a image with mean and standard deviation.
 
@@ -1702,7 +1725,7 @@ class NormalizeTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="RandomCrop", process="preprocess", \
-                framework="mxnet, onnxrt_qlinearops, onnxrt_integerops")
+                framework="onnxrt_qdqops, mxnet, onnxrt_qlinearops, onnxrt_integerops")
 class RandomCropTransform(BaseTransform):
     """Crop the image at a random location to the given size.
 
@@ -1742,7 +1765,7 @@ class RandomCropTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="RandomResizedCrop", process="preprocess", \
-                framework="onnxrt_qlinearops, onnxrt_integerops")
+                framework="onnxrt_qdqops, onnxrt_qlinearops, onnxrt_integerops")
 class RandomResizedCropTransform(BaseTransform):
     """Crop the given image to random size and aspect ratio.
 
