@@ -43,11 +43,16 @@ class PyTorchMetrics(object):
 @singleton
 class MXNetMetrics(object):
     def __init__(self):
+        from ...adaptor.mxnet_utils.util import check_mx_version
+        if check_mx_version('2.0.0'):
+            import mxnet.gluon.metric as mx_metrics
+        else:
+            import mxnet.metric as mx_metrics
         self.metrics = {
-            "Accuracy": WrapMXNetMetric(mx.metric.Accuracy),
-            "MAE": WrapMXNetMetric(mx.metric.MAE),
-            "MSE": WrapMXNetMetric(mx.metric.MSE),
-            "Loss": WrapMXNetMetric(mx.metric.Loss),
+            "Accuracy": WrapMXNetMetric(mx_metrics.Accuracy),
+            "MAE": WrapMXNetMetric(mx_metrics.MAE),
+            "MSE": WrapMXNetMetric(mx_metrics.MSE),
+            "Loss": WrapMXNetMetric(mx_metrics.Loss),
         }
         self.metrics.update(MXNET_METRICS)
 
@@ -63,6 +68,12 @@ class ONNXRTITMetrics(object):
         self.metrics = {}
         self.metrics.update(ONNXRT_IT_METRICS)
 
+@singleton
+class ONNXRTQDQMetrics(object):
+    def __init__(self):
+        self.metrics = {}
+        self.metrics.update(ONNXRT_QDQ_METRICS)
+
 @singleton
 class EngineMetrics(object):
     def __init__(self):
@@ -77,6 +88,7 @@ framework_metrics = {"tensorflow": TensorflowMetrics,
                      "pytorch_fx": PyTorchMetrics,
                      "onnxrt_qlinearops": ONNXRTQLMetrics,
                      "onnxrt_integerops": ONNXRTITMetrics,
+                     "onnxrt_qdqops": ONNXRTQDQMetrics,
                      "engine": EngineMetrics}
 
 # user/model specific metrics will be registered here
@@ -84,6 +96,7 @@ TENSORFLOW_METRICS = {}
 MXNET_METRICS = {}
 PYTORCH_METRICS = {}
 ONNXRT_QL_METRICS = {}
+ONNXRT_QDQ_METRICS = {}
 ONNXRT_IT_METRICS = {}
 ENGINE_METRICS = {}
 
@@ -94,6 +107,7 @@ registry_metrics = {"tensorflow": TENSORFLOW_METRICS,
                     "pytorch_ipex": PYTORCH_METRICS,
                     "pytorch_fx": PYTORCH_METRICS,
                     "onnxrt_qlinearops": ONNXRT_QL_METRICS,
+                    "onnxrt_qdqops": ONNXRT_QDQ_METRICS,
                     "onnxrt_integerops": ONNXRT_IT_METRICS,
                     "engine": ENGINE_METRICS,}
 
@@ -101,7 +115,7 @@ registry_metrics = {"tensorflow": TENSORFLOW_METRICS,
 class METRICS(object):
     def __init__(self, framework):
         assert framework in ("tensorflow", "tensorflow_itex", "engine",
-                            "pytorch", "pytorch_ipex", "pytorch_fx", \
+                            "pytorch", "pytorch_ipex", "pytorch_fx", "onnxrt_qdqops", \
                              "onnxrt_qlinearops", "onnxrt_integerops", "mxnet"), \
                              "framework support tensorflow pytorch mxnet onnxrt engine"
         self.metrics = framework_metrics[framework]().metrics
@@ -135,6 +149,7 @@ def metric_registry(metric_type, framework):
                 "mxnet",
                 "onnxrt_qlinearops",
                 "onnxrt_integerops",
+                "onnxrt_qdqops",
                 "pytorch",
                 "pytorch_ipex",
                 "pytorch_fx",
@@ -295,7 +310,7 @@ def _shape_validate(preds, labels):
     return preds, labels
 
 @metric_registry('F1', 'tensorflow, pytorch, mxnet, onnxrt_qlinearops, \
-                 onnxrt_integerops, engine')
+                        onnxrt_qdqops, onnxrt_integerops, engine')
 class F1(BaseMetric):
     """Computes the F1 score of a binary classification problem.
 
@@ -355,7 +370,7 @@ def _accuracy_type_check(preds, labels):
    return update_type
 
 @metric_registry('Accuracy', 'tensorflow, pytorch, onnxrt_qlinearops, \
-                onnxrt_integerops, engine')
+                              onnxrt_qdqops, onnxrt_integerops, engine')
 class Accuracy(BaseMetric):
     """Computes accuracy classification score.
 
@@ -435,7 +450,8 @@ class PyTorchLoss():
                                       before it can be computed.")
         return self._sum.item() / self._num_examples
         
-@metric_registry('Loss', 'tensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('Loss', 'tensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops, engine, \
+                         onnxrt_qdqops')
 class Loss(BaseMetric):
     """A dummy metric for directly printing loss, it calculates the average of predictions.
 
@@ -463,7 +479,8 @@ class Loss(BaseMetric):
             return allgather_sum / allgather_sample
         return self.sum / self.sample
 
-@metric_registry('MAE', 'tensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('MAE', 'tensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops, engine, \
+                         onnxrt_qdqops')
 class MAE(BaseMetric):
     """Computes Mean Absolute Error (MAE) loss.
 
@@ -499,7 +516,7 @@ class MAE(BaseMetric):
         return aes_sum / aes_size
 
 @metric_registry('RMSE', 'tensorflow, pytorch, mxnet, onnxrt_qlinearops, \
-                onnxrt_integerops, engine')
+                          onnxrt_qdqops, onnxrt_integerops, engine')
 class RMSE(BaseMetric):
     """Computes Root Mean Squared Error (RMSE) loss.
 
@@ -524,7 +541,8 @@ class RMSE(BaseMetric):
             self.mse._hvd = self._hvd
         return np.sqrt(self.mse.result())
 
-@metric_registry('MSE', 'tensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('MSE', 'tensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops, \
+                         onnxrt_qdqops, engine')
 class MSE(BaseMetric):
     """Computes Mean Squared Error (MSE) loss.
 
@@ -604,7 +622,8 @@ class TensorflowTopK(BaseMetric):
             return allgather_num_correct / allgather_num_sample 
         return self.num_correct / self.num_sample
 
-@metric_registry('topk', 'pytorch, mxnet, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('topk', 'pytorch, mxnet, onnxrt_qlinearops, onnxrt_integerops, \
+                          engine, onnxrt_qdqops')
 class GeneralTopK(BaseMetric):
     """Computes top k predictions accuracy.
 
@@ -650,7 +669,8 @@ class GeneralTopK(BaseMetric):
             return allgather_num_correct / allgather_num_sample
         return self.num_correct / self.num_sample
 
-@metric_registry('COCOmAPv2', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('COCOmAPv2', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, \
+                               onnxrt_qdqops, engine')
 class COCOmAPv2(BaseMetric):
     """Computes mean average precision.
     Args:
@@ -797,7 +817,8 @@ class COCOmAPv2(BaseMetric):
 
             return box_metrics[self.map_key]
 
-@metric_registry('mAP', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('mAP', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, \
+                         onnxrt_qdqops, engine')
 class TensorflowMAP(BaseMetric):
     """Computes mean average precision.
 
@@ -945,7 +966,8 @@ class TensorflowMAP(BaseMetric):
 
             return box_metrics[self.map_key]
 
-@metric_registry('COCOmAP', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('COCOmAP', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, \
+                             onnxrt_qdqops, engine')
 class TensorflowCOCOMAP(TensorflowMAP):
     """Computes mean average precision using algorithm in COCO
 
@@ -961,7 +983,8 @@ class TensorflowCOCOMAP(TensorflowMAP):
         self.iou_thrs = '0.5:0.05:0.95'
         self.map_points = 101
 
-@metric_registry('VOCmAP', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('VOCmAP', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, \
+                            onnxrt_qdqops, engine')
 class TensorflowVOCMAP(TensorflowMAP):
     """Computes mean average precision using algorithm in VOC
 
@@ -1049,7 +1072,7 @@ class mIOU(BaseMetric):
         mean_iu = np.nanmean(iu)
         return mean_iu
 
-@metric_registry('GLUE', 'onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('GLUE', 'onnxrt_qlinearops, onnxrt_integerops, engine, onnxrt_qdqops')
 class ONNXRTGLUE(BaseMetric):
     """Computes GLUE score.
 
