@@ -278,21 +278,45 @@ class Quantization(Component):
         if deep_get(self.conf.usr_cfg, "evaluation.accuracy.metric"):
             logger.warning("Override the value of `metric` field defined in yaml file" \
                            " as user defines the value of `metric` attribute by code.")
- 
+
         from .common import Metric as NCMetric
+        from ..metric import METRICS
         if isinstance(user_metric, NCMetric):
-            metric_cfg = {user_metric.name : {**user_metric.kwargs}}
-            deep_set(self.conf.usr_cfg, "evaluation.accuracy.metric", metric_cfg)
-            self.conf.usr_cfg = DotDict(self.conf.usr_cfg)
-            from ..metric import METRICS
-            metrics = METRICS(self.framework)
-            metrics.register(user_metric.name, user_metric.metric_cls)
+            name = user_metric.name
+            metric_cls = user_metric.metric_cls
+            metric_cfg = {name: {**user_metric.kwargs}}
         else:
             for i in ['reset', 'update', 'result']:
                 assert hasattr(user_metric, i), 'Please realise {} function' \
                                                 'in user defined metric'.format(i)
-            self._metric = user_metric
+            metric_cls = type(user_metric).__name__
+            name = 'user_' + metric_cls
+            metric_cfg = {name: id(user_metric)}
+        deep_set(self.conf.usr_cfg, "evaluation.accuracy.metric", metric_cfg)
+        self.conf.usr_cfg = DotDict(self.conf.usr_cfg)
+        metrics = METRICS(self.framework)
+        metrics.register(name, metric_cls)
+        self._metric = user_metric
+ 
+    @property
+    def objective(self):
+        assert False, 'Should not try to get the value of `objective` attribute.'
+        return None
 
+    @objective.setter
+    def objective(self, user_objective):
+        if deep_get(self.conf.usr_cfg, "tuning.multi_objective.objective"):
+            logger.warning("Override the value of `objective` field defined in yaml file" \
+                           " as user defines the value of `objective` attribute by code.")
+
+        from ..objective import objective_custom_registry
+        objective_cls = type(user_objective)
+        name = user_objective.__class__.__name__
+        objective_cfg = [name]
+        deep_set(self.conf.usr_cfg, "tuning.multi_objective.objective", objective_cfg)
+        self.conf.usr_cfg = DotDict(self.conf.usr_cfg)
+        objective_custom_registry(name, objective_cls)
+    
     @property
     def postprocess(self, user_postprocess):
         assert False, 'Should not try to get the value of `postprocess` attribute.'
