@@ -118,7 +118,11 @@ class MSETuneStrategy(TuneStrategy):
         # Model wise tuning
         op_cfgs = {}
         best_cfg = None
-        best_acc = float('-inf') if self.higher_is_better else float('inf')
+        if len(self.metric_name) == 1 or self.metric_weight is not None:
+            best_acc = float('-inf') if self.higher_is_better else float('inf')
+        else:
+            best_acc = [float('-inf') if higher_is_better else float('inf') for \
+                higher_is_better in self.metric_criterion]
 
         for i, iterations in enumerate(self.calib_iter):
             op_cfgs['calib_iteration'] = int(iterations)
@@ -135,10 +139,23 @@ class MSETuneStrategy(TuneStrategy):
 
                 yield op_cfgs
                 acc, _ = self.last_tune_result
-                if (self.higher_is_better and acc > best_acc) or \
-                    (not self.higher_is_better and acc < best_acc):
+
+                if not isinstance(acc, list) and ((self.higher_is_better and acc >= best_acc) \
+                    or (not self.higher_is_better and acc <= best_acc)):
                     best_acc = acc
                     best_cfg = copy.deepcopy(op_cfgs)
+                elif len(self.metric_name) > 1 and self.metric_weight is not None:
+                    acc = np.mean(np.array(acc) * self.metric_weight)
+                    if (self.higher_is_better and acc >= best_acc) or \
+                        (not self.higher_is_better and acc <= best_acc):
+                        best_acc = acc
+                        best_cfg = copy.deepcopy(op_cfgs)
+                elif len(self.metric_name) > 1 and self.metric_weight is None:
+                    if all([acc_i >= best_i if higher_is_better else acc_i <= best_i for \
+                        acc_i, best_i, higher_is_better in \
+                        zip(acc, best_acc, self.metric_criterion)]):
+                        best_acc = acc
+                        best_cfg = copy.deepcopy(op_cfgs)
 
         if best_cfg is not None:
             # Inspect FP32 and dequantized tensor
@@ -174,11 +191,27 @@ class MSETuneStrategy(TuneStrategy):
                         op_cfgs['op'][op]['weight']['dtype'] = 'fp32'
                     yield op_cfgs
                     acc, _ = self.last_tune_result
-                    if (self.higher_is_better and acc <= best_acc) or \
-                        (not self.higher_is_better and acc >= best_acc):
-                        op_cfgs['op'][op] = copy.deepcopy(old_cfg)
-                    else:
-                        best_acc = acc
+
+                    if not isinstance(acc, list):
+                        if ((self.higher_is_better and acc <= best_acc) \
+                            or (not self.higher_is_better and acc >= best_acc)):
+                            op_cfgs['op'][op] = copy.deepcopy(old_cfg)
+                        else:
+                            best_acc = acc
+                    elif len(self.metric_name) > 1 and self.metric_weight is not None:
+                        acc = np.mean(np.array(acc) * self.metric_weight)
+                        if (self.higher_is_better and acc <= best_acc) or \
+                            (not self.higher_is_better and acc >= best_acc):
+                            op_cfgs['op'][op] = copy.deepcopy(old_cfg)
+                        else:
+                            best_acc = acc
+                    elif len(self.metric_name) > 1 and self.metric_weight is None:
+                        if all([acc_i >= best_i if higher_is_better else acc_i <= best_i for \
+                            acc_i, best_i, higher_is_better in \
+                            zip(acc, best_acc, self.metric_criterion)]):
+                            op_cfgs['op'][op] = copy.deepcopy(old_cfg)
+                        else:
+                            best_acc = acc
 
                 op_cfgs = copy.deepcopy(best_cfg)
                 for op in ordered_ops:
