@@ -4,7 +4,6 @@ import unittest
 
 import torch
 import torchvision
-import yaml
 import onnx
 import numpy as np
 from collections import OrderedDict
@@ -17,6 +16,7 @@ from neural_compressor.experimental import Benchmark, common
 from neural_compressor import options
 from neural_compressor.adaptor.pytorch import get_torch_version, PyTorchVersionMode
 from neural_compressor import conf
+from onnxruntime_extensions import onnx_op
 
 def build_static_yaml():
     fake_yaml = """
@@ -49,7 +49,40 @@ def build_static_yaml():
           workspace: 
             path: ./nc_workspace/recover/
         """
-    with open("static.yaml", "w", encoding="utf-8") as f:
+    with open("qlinear.yaml", "w", encoding="utf-8") as f:
+        f.write(fake_yaml)
+
+    fake_yaml = """
+        model:
+          name: imagenet
+          framework: onnxrt_qdqops
+
+        quantization:                                        
+          approach: post_training_static_quant  
+          calibration:
+            sampling_size: 50
+          op_wise: {
+            'Gather_*': {
+            'activation':  {'dtype': ['fp32'], 'scheme':['sym']},
+            'weight': {'dtype': ['fp32'], 'scheme':['sym']}
+            }
+          }
+ 
+        evaluation:
+          accuracy:
+            metric:
+              topk: 1
+
+        tuning:
+          accuracy_criterion:
+            relative:  0.01
+          exit_policy:
+            timeout: 0
+          random_seed: 9527
+          workspace: 
+            path: ./nc_workspace/recover/
+        """
+    with open("qdq.yaml", "w", encoding="utf-8") as f:
         f.write(fake_yaml)
 
 def build_benchmark_yaml():
@@ -306,6 +339,27 @@ def build_rename_model():
     model = helper.make_model(graph, **{'opset_imports': [helper.make_opsetid('', 13)]})
     return model
 
+@onnx_op(op_type="PyReverseMatrix")
+def reverse_matrix(x):
+    # The user custom op implementation here.
+    return np.flip(x, axis=0).astype(np.float32)
+
+def build_ext_model():
+    nodes = []
+    nodes[0:] = [helper.make_node('Identity', ['input_1'], ['identity1'])]
+    nodes[1:] = [helper.make_node('PyReverseMatrix',
+                                  ['identity1'], ['reversed'],
+                                  domain='ai.onnx.contrib')]
+
+    input0 = helper.make_tensor_value_info(
+            'input_1', onnx_proto.TensorProto.FLOAT, [None, 2])
+    output0 = helper.make_tensor_value_info(
+            'reversed', onnx_proto.TensorProto.FLOAT, [None, 2])
+
+    graph = helper.make_graph(nodes, 'test0', [input0], [output0])
+    model = helper.make_model(graph, **{'opset_imports': [helper.make_opsetid('', 13)]})
+    return model
+
 class MatmulDataset:
     def __init__(self):
         self.data = []
@@ -338,6 +392,9 @@ class TestAdaptorONNXRT(unittest.TestCase):
     gather_dataset = DATASETS('onnxrt_qlinearops')['dummy'](shape=(5, 100, 4), label=True)
     gather_dataloader = DATALOADERS['onnxrt_qlinearops'](gather_dataset)
 
+    ext_dataset = datasets['dummy'](shape=(10, 2), low=0., high=1., label=True)
+    ext_dataloader = DATALOADERS['onnxrt_qlinearops'](ext_dataset)
+
     rename_dataloader = gather_dataloader
 
     matmul_dataset = MatmulDataset()
@@ -360,10 +417,12 @@ class TestAdaptorONNXRT(unittest.TestCase):
         self.gather_model = build_model_with_gather()
         self.matmul_model = build_matmul_model()
         self.rename_model = build_rename_model()
+        self.ext_model = build_ext_model()
 
     @classmethod
     def tearDownClass(self):
-        os.remove("static.yaml")
+        os.remove("qlinear.yaml")
+        os.remove("qdq.yaml")
         os.remove("dynamic.yaml")
         os.remove("non_MSE.yaml")
         os.remove("benchmark.yaml")
@@ -377,6 +436,15 @@ class TestAdaptorONNXRT(unittest.TestCase):
         shutil.rmtree("runs", ignore_errors=True)
         shutil.rmtree("./nc_workspace", ignore_errors=True)
 
+    def test_ext_model(self):
+        from neural_compressor.experimental import Benchmark
+        conf.model.framework = 'onnxrt_qlinearops'
+        conf.evaluation.accuracy.metric = {'Accuracy': {}}
+        evaluator = Benchmark(conf)
+        evaluator.b_dataloader = self.ext_dataloader
+        evaluator.model = self.ext_model
+        evaluator('performance')
+
     def test_adaptor_register(self):
         from neural_compressor.adaptor.adaptor import adaptor_registry
         def test():
@@ -414,7 +482,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
     def test_set_tensor(self):
         options.onnxrt.graph_optimization.level = 'ENABLE_EXTENDED'
         options.onnxrt.graph_optimization.gemm2matmul = False
-        quantizer = Quantization("static.yaml")
+        quantizer = Quantization("qlinear.yaml")
         quantizer.calib_dataloader = self.cv_dataloader
         quantizer.eval_dataloader = self.cv_dataloader
         quantizer.model = self.mb_v2_model
@@ -449,33 +517,37 @@ class TestAdaptorONNXRT(unittest.TestCase):
         conf.model.framework = 'onnxrt_integerops'
         conf.quantization.approach = 'post_training_dynamic_quant'
         conf.quantization.calibration.sampling_size = 1
-        conf.evaluation.accuracy.metric = {'Accuracy': {}}
-        quantizer = Quantization()
+        conf.evaluation.accuracy.metric = {'MSE': {'compare_label': False}}
         quantizer = Quantization(conf)
         quantizer.calib_dataloader = self.rename_dataloader
         quantizer.eval_dataloader = self.rename_dataloader
         quantizer.model = self.rename_model
         q_model = quantizer.fit()
+        self.assertNotEqual(q_model, None)
 
-        for fake_yaml in ["static.yaml", "dynamic.yaml"]:
+        
+        for fake_yaml in ["qlinear.yaml", "qdq.yaml", "dynamic.yaml"]:
             quantizer = Quantization(fake_yaml)
             quantizer.calib_dataloader = self.cv_dataloader
             quantizer.eval_dataloader = self.cv_dataloader
             quantizer.model = self.rn50_model
             q_model = quantizer.fit()
-            eval_func(q_model)
+            self.assertNotEqual(q_model, None)
 
         import copy
         tmp_model = copy.deepcopy(self.rn50_model)
         tmp_model.opset_import[0].version = 10
         quantizer.model = tmp_model
         q_model = quantizer.fit()
+        self.assertNotEqual(q_model, None)
         tmp_model.opset_import.extend([onnx.helper.make_opsetid("", 11)]) 
         quantizer.model = tmp_model
         q_model = quantizer.fit()
+        self.assertEqual(q_model, None)
         model = onnx.load('rn50_9.onnx')
         quantizer.model = model
         q_model = quantizer.fit()
+        self.assertNotEqual(q_model, None)
 
         framework_specific_info = {"device": "cpu",
                      "approach": "post_training_static_quant",
@@ -502,17 +574,21 @@ class TestAdaptorONNXRT(unittest.TestCase):
             quantizer = Quantization(fake_yaml)
             quantizer.model = self.gather_model
             q_model = quantizer.fit()
+            self.assertNotEqual(q_model, None)
 
             quantizer.model = self.matmul_model
-            q_model = quantizer.fit()
+            q_model = quantizer.fit() # error input shape test
+            self.assertEqual(q_model, None)
 
             quantizer.eval_dataloader = self.matmul_dataloader
-            q_model = quantizer.fit()
+            q_model = quantizer.fit() # error input shape test
+            self.assertEqual(q_model, None)
 
             quantizer.calib_dataloader = self.matmul_dataloader
             quantizer.eval_dataloader = self.matmul_dataloader
             quantizer.model = self.matmul_model
             q_model = quantizer.fit()
+            self.assertNotEqual(q_model, None)
 
         options.onnxrt.graph_optimization.level = 'ENABLE_BASIC'
         for fake_yaml in ["non_MSE.yaml"]:
@@ -521,19 +597,31 @@ class TestAdaptorONNXRT(unittest.TestCase):
             quantizer.eval_dataloader = self.cv_dataloader
             quantizer.model = self.mb_v2_model
             q_model = quantizer.fit()
-            eval_func(q_model)
+            self.assertNotEqual(q_model, None)
 
-        for fake_yaml in ["static.yaml"]:
+        options.onnxrt.qdq_setting.AddQDQPairToWeight = True
+        for fake_yaml in ["qlinear.yaml", "qdq.yaml"]:
             quantizer = Quantization(fake_yaml)
             quantizer.calib_dataloader = self.ir3_dataloader
             quantizer.eval_dataloader = self.ir3_dataloader
             quantizer.model = self.ir3_model
             q_model = quantizer.fit()
+            self.assertNotEqual(q_model, None)
 
             from neural_compressor.utils.utility import recover
             model = recover(self.ir3_model, './nc_workspace/recover/history.snapshot', 0)
             self.assertTrue(model.model == q_model.model)
 
+        options.onnxrt.qdq_setting.DedicatedQDQPair = True
+        options.onnxrt.qdq_setting.OpTypesToExcludeOutputQuantizatioin = ['Conv']
+        for fake_yaml in ["qdq.yaml"]:
+            quantizer = Quantization(fake_yaml)
+            quantizer.calib_dataloader = self.cv_dataloader
+            quantizer.eval_dataloader = self.cv_dataloader
+            quantizer.model = self.rn50_model
+            q_model = quantizer.fit()
+            self.assertNotEqual(q_model, None)
+
         for mode in ["performance", "accuracy"]:
             fake_yaml = "benchmark.yaml"
             evaluator = Benchmark(fake_yaml)
@@ -570,5 +658,77 @@ class TestAdaptorONNXRT(unittest.TestCase):
         self.assertTrue('add' in node_names)
         self.assertTrue('add2_quant' in node_names)
     
+    def test_multi_metrics(self):
+        conf.model.framework = 'onnxrt_qlinearops'
+        conf.quantization.approach = 'post_training_static_quant'
+        conf.evaluation.accuracy.multi_metrics = {'Accuracy': {}, 'MSE': {'compare_label': False}}
+        conf.evaluation.accuracy.pop('metric', None)
+        from neural_compressor.experimental import Quantization
+        quantizer = Quantization(conf)
+        quantizer.eval_dataloader = self.cv_dataloader
+        quantizer.calib_dataloader = self.cv_dataloader
+        quantizer.model = self.rn50_model
+        q_model = quantizer.fit()
+        self.assertNotEqual(q_model, None)
+
+        conf.evaluation.accuracy.multi_metrics = {
+            'Accuracy': {}, 'MSE': {'compare_label': False}, 'higher_is_better': [False, False]}
+        conf.tuning.exit_policy.max_trials = 1
+        from neural_compressor.experimental import Quantization
+        quantizer = Quantization(conf)
+        quantizer.eval_dataloader = self.cv_dataloader
+        quantizer.calib_dataloader = self.cv_dataloader
+        quantizer.model = self.rn50_model
+        q_model = quantizer.fit()
+        self.assertEqual(q_model, None)
+
+        conf.tuning.accuracy_criterion.higher_is_better = True
+        conf.evaluation.accuracy.multi_metrics = {
+            'Accuracy': {}, 'MSE': {'compare_label': False}, 'weight': [0.5, 0.5]}
+        from neural_compressor.experimental import Quantization
+        quantizer = Quantization(conf)
+        quantizer.eval_dataloader = self.cv_dataloader
+        quantizer.calib_dataloader = self.cv_dataloader
+        quantizer.model = self.rn50_model
+        q_model = quantizer.fit()
+        self.assertNotEqual(q_model, None)
+
+        conf.evaluation.accuracy.multi_metrics = {
+            'Accuracy': {}, 'MSE': {'compare_label': False}, 'weight': [0.5, 0.5], 
+            'higher_is_better': [False, False]}
+        from neural_compressor.experimental import Quantization
+        quantizer = Quantization(conf)
+        quantizer.eval_dataloader = self.cv_dataloader
+        quantizer.calib_dataloader = self.cv_dataloader
+        quantizer.model = self.rn50_model
+        q_model = quantizer.fit()
+        self.assertNotEqual(q_model, None)
+
+        conf.evaluation.accuracy.multi_metrics = {
+            'Accuracy': {}, 'MSE': {'compare_label': False}, 'weight': [0.5, 0.5], 
+            'higher_is_better': [False, False]}
+        conf.tuning.accuracy_criterion.higher_is_better = False
+        conf.tuning.exit_policy.max_trials = 2
+        from neural_compressor.experimental import Quantization
+        quantizer = Quantization(conf)
+        quantizer.eval_dataloader = self.cv_dataloader
+        quantizer.calib_dataloader = self.cv_dataloader
+        quantizer.model = self.rn50_model
+        q_model = quantizer.fit()
+        self.assertEqual(q_model, None)
+
+        conf.evaluation.accuracy.multi_metrics = {
+            'Accuracy': {}, 'MSE': {'compare_label': False}, 'higher_is_better': [False, False]}
+        conf.tuning.exit_policy.max_trials = 1
+        conf.tuning.accuracy_criterion = {'absolute': 0.01, 'higher_is_better': False}
+        from neural_compressor.experimental import Quantization
+        quantizer = Quantization(conf)
+        quantizer.eval_dataloader = self.cv_dataloader
+        quantizer.calib_dataloader = self.cv_dataloader
+        quantizer.model = self.rn50_model
+        q_model = quantizer.fit()
+        self.assertEqual(q_model, None)
+
+
 if __name__ == "__main__":
     unittest.main()
