@@ -318,7 +318,6 @@ class M(torch.nn.Module):
         self.dequant = DeQuantStub()
 
     def forward(self, x):
-        dim = x.size()
         x = self.quant(x)
         x = self.conv(x)
         x = x.view(1, -1)
@@ -328,30 +327,48 @@ class M(torch.nn.Module):
 
 
 class FP32Model(torch.nn.Module):
+    def __init__(self):
+        super().__init__()
+
+    def forward(self, x):
+        times = x.size(1)
+        if times == 1:
+            return x + x
+        return x
+
+
+class DynamicModel(torch.nn.Module):
     def __init__(self):
         super().__init__()
         self.conv = nn.Conv2d(1, 1, 1)
     def forward(self, x):
-        x = self.conv(x)
+        if x is not None:
+            x = self.conv(x)
         return x
 
 
 class SubModel(torch.nn.Module):
-    def __init__(self):
+    def __init__(self, bypass=True):
         super().__init__()
         self.quant = QuantStub()
         self.conv = nn.Conv2d(1, 1, 1)
         self.conv1 = nn.Conv2d(1, 1, 1)
+        self.bn = nn.BatchNorm2d(1)
+        self.relu = nn.ReLU()
         self.fp32 = FP32Model()
         self.norm = nn.LayerNorm([1, 224, 224])
         self.dequant = DeQuantStub()
+        self.bypass = bypass
 
     def forward(self, x):
         x = self.conv(x)
+        x = self.bn(x)
         x = self.quant(x)
+        x = self.relu(x)
         x = self.conv1(x)
         x = self.dequant(x)
-        x = self.fp32(x)
+        if not self.bypass:
+            x = self.fp32(x)
         x = self.norm(x)
         return x
 
@@ -367,7 +384,7 @@ class PartialQuantModel(torch.nn.Module):
         self.conv2 = nn.Conv2d(1, 1, 1)
         self.linear = nn.Linear(224 * 224, 1)
         self.dequant = DeQuantStub()
-        self.sub = SubModel()
+        self.sub = SubModel(bypass=False)
 
     def forward(self, x):
         x = self.conv(x)
@@ -382,6 +399,26 @@ class PartialQuantModel(torch.nn.Module):
         x = self.dequant(x)
         return x
 
+class DynamicControlModel(torch.nn.Module):
+    def __init__(self):
+        super().__init__()
+        self.conv = nn.Conv2d(3, 1, 1)
+        self.bn = nn.BatchNorm2d(1)
+        self.linear = nn.Linear(224 * 224, 1)
+        self.sub = SubModel()
+        self.fp32 = FP32Model()
+        self.dyn = DynamicModel()
+
+    def forward(self, x):
+        x = self.conv(x)
+        x = self.dyn(x)
+        x = self.bn(x)
+        x = self.sub(x)
+        x = self.fp32(x)
+        x = x.view(1, -1)
+        x = self.linear(x)
+        return x
+
 
 def eval_func(model):
     # switch to evaluate mode
@@ -490,16 +527,17 @@ class TestPytorchAdaptor(unittest.TestCase):
             quantizer.calib_dataloader = common.DataLoader(dataset)
             quantizer.eval_dataloader = common.DataLoader(dataset)
             q_model = quantizer.fit()
+            eval_func(q_model)
             q_model.save('./saved')
             # Load configure and weights by neural_compressor.utils
             saved_model = load("./saved", model)
-            # recover int8 model with only tune_cfg
-            tune_cfg_file = './saved/best_configure.yaml'
-            with open(tune_cfg_file, 'r') as f:
-                history_cfg = yaml.safe_load(f)
-            saved_model = load(model=model, \
-                                history_cfg=history_cfg)
             eval_func(saved_model)
+            # recover int8 model from history
+            history_file = './saved/history.snapshot'
+            model_recover = recover(model, history_file, 0)
+            eval_func(model_recover)
+            self.assertEqual(type(saved_model.conv), \
+                             type(model_recover.conv))
             shutil.rmtree('./saved', ignore_errors=True)
         from neural_compressor.experimental import Benchmark
         evaluator = Benchmark('ptq_yaml.yaml')
@@ -527,15 +565,30 @@ class TestPytorchAdaptor(unittest.TestCase):
             q_model.save('./saved')
             # Load configure and weights by neural_compressor.utils
             saved_model = load("./saved", model)
-            # recover int8 model with only tune_cfg
-            tune_cfg_file = './saved/best_configure.yaml'
-            with open(tune_cfg_file, 'r') as f:
-                history_cfg = yaml.safe_load(f)
-            saved_model = load(model=model, \
-                                history_cfg=history_cfg)
             eval_func(saved_model)
             shutil.rmtree('./saved', ignore_errors=True)
 
+    def test_quantization_new_saved(self):
+        for fake_yaml in ['dynamic_yaml.yaml', 'qat_yaml.yaml', 'ptq_yaml.yaml']:
+            model = M()
+            quantizer = Quantization(fake_yaml)
+            quantizer.conf.usr_cfg.tuning.exit_policy['performance_only'] = True
+            dataset = quantizer.dataset('dummy', (100, 3, 224, 224), label=True)
+            quantizer.model = model
+            quantizer.calib_dataloader = common.DataLoader(dataset)
+            quantizer.eval_dataloader = common.DataLoader(dataset)
+            q_model = quantizer.fit()
+            eval_func(q_model)
+            torch.save(q_model.quantized_state_dict(), './saved/model.pt')
+            # Load configure and weights by neural_compressor.utils
+            from neural_compressor.experimental.common import Model
+            common_model = Model(model)
+            common_model.load_quantized_state_dict(torch.load('./saved/model.pt'))
+            eval_func(common_model)
+            self.assertEqual(type(q_model._model.linear), \
+                             type(common_model._model.linear))
+            shutil.rmtree('./saved', ignore_errors=True)
+
     def test_non_quant_module(self):
         for fake_yaml in ['qat_yaml.yaml', 'ptq_yaml.yaml']:
             model = PartialQuantModel()
@@ -556,6 +609,32 @@ class TestPytorchAdaptor(unittest.TestCase):
             eval_func(saved_model)
             shutil.rmtree('./saved', ignore_errors=True)
 
+    def test_workspace_path(self):
+        model = M()
+        quantizer = Quantization('ptq_yaml.yaml')
+        quantizer.conf.usr_cfg.tuning.exit_policy['performance_only'] = True
+        dataset = quantizer.dataset('dummy', (100, 3, 224, 224), label=True)
+        quantizer.model = model
+        quantizer.calib_dataloader = common.DataLoader(dataset)
+        quantizer.eval_dataloader = common.DataLoader(dataset)
+        q_model = quantizer.fit()
+        eval_func(q_model)
+        torch.save(q_model.quantized_state_dict(), './saved/best_model.pt')
+        # Load configure and weights by workspace_path
+        from neural_compressor.experimental.common import Model
+        common_model = Model(model)
+        common_model.workspace_path = './saved'
+        eval_func(common_model)
+        self.assertEqual(type(q_model._model.linear), \
+                          type(common_model._model.linear))
+        shutil.rmtree('./saved', ignore_errors=True)
+
+    def test_get_graph_info(self):
+        from neural_compressor.model.torch_model import PyTorchModel
+        model = PyTorchModel(self.model)
+        op_map = model.graph_info
+        self.assertTrue(op_map['conv1'] == 'Conv2d')
+
     def test_tensorboard(self):
         model = copy.deepcopy(self.nc_model)
         model.model.eval().fuse_model()
@@ -792,6 +871,7 @@ class TestPytorchFXAdaptor(unittest.TestCase):
                                     {'preserved_attributes': []}
                               })
             self.assertTrue(isinstance(model_fx, torch.fx.graph_module.GraphModule))
+            shutil.rmtree('./saved', ignore_errors=True)
 
     @unittest.skipIf(PT_VERSION < PyTorchVersionMode.PT19.value,
       "Please use PyTroch 1.9 or higher version for dynamic quantization with pytorch_fx backend")
@@ -861,7 +941,44 @@ class TestPytorchFXAdaptor(unittest.TestCase):
         self.assertEqual(model_fx.code, model_fx_recover.code)
         shutil.rmtree('./saved', ignore_errors=True)
 
+    def test_fx_sub_module_quant(self):
+        for fake_yaml in ['fx_qat_yaml.yaml', 'fx_ptq_yaml.yaml']:
+            model_origin = DynamicControlModel()
+            # run fx_quant in neural_compressor and save the quantized GraphModule
+            quantizer = Quantization(fake_yaml)
+            dataset = quantizer.dataset('dummy', (1, 3, 224, 224), label=True)
+            quantizer.eval_func = eval_func
+            if fake_yaml == 'fx_qat_yaml.yaml':
+                quantizer.q_func = q_func
+            else:
+                quantizer.calib_dataloader = common.DataLoader(dataset)
+            quantizer.model = common.Model(model_origin,
+                            **{'prepare_custom_config_dict': \
+                                    {'non_traceable_module_name': ['a']},
+                               'convert_custom_config_dict': \
+                                    {'preserved_attributes': []}
+                              })
+            q_model = quantizer.fit()
+            q_model.save('./saved')
+            # Load configure and weights with neural_compressor.utils
+            model_fx = load('./saved/best_model.pt', model_origin,
+                            **{'prepare_custom_config_dict': \
+                                    {'non_traceable_module_name': ['a']},
+                               'convert_custom_config_dict': \
+                                    {'preserved_attributes': []}
+                              })
+            self.assertTrue(isinstance(model_fx.sub, torch.fx.graph_module.GraphModule))
 
+            # recover int8 model with only tune_cfg
+            history_file = './saved/history.snapshot'
+            model_fx_recover = recover(model_origin, history_file, 0,
+                            **{'prepare_custom_config_dict': \
+                                    {'non_traceable_module_name': ['a']},
+                               'convert_custom_config_dict': \
+                                    {'preserved_attributes': []}
+                              })
+            self.assertEqual(model_fx.sub.code, model_fx_recover.sub.code)
+            shutil.rmtree('./saved', ignore_errors=True)
 
 if __name__ == "__main__":
     unittest.main()
