@@ -282,17 +282,6 @@ class TestConf(unittest.TestCase):
         helper(test)
         self.assertRaises(RuntimeError, conf.Conf, 'fake_conf.yaml')
 
-        test = '''
-        model:
-          name: tuning_yaml 
-          framework: mxnet
-        tuning:
-          accuracy_criterion:
-          relative: 0.01
-        '''
-        helper(test)
-        self.assertRaises(RuntimeError, conf.Conf, 'fake_conf.yaml')
-
         test = '''
         model:
           name: tuning_yaml 
@@ -366,6 +355,77 @@ class TestConf(unittest.TestCase):
         config = conf.Conf('fake_conf.yaml')
         self.assertEqual(config.usr_cfg.model.inputs, ['x', 'y'])
 
+    def test_objective(self):
+        test = '''
+        model:
+          name: inout_yaml 
+          framework: mxnet
+          inputs: x, y
+        tuning:
+          multi_objectives:
+            objective: accuracy
+            higher_is_better: True
+        '''
+        helper(test)
+        config = conf.Conf('fake_conf.yaml')
+        self.assertEqual(config.usr_cfg.tuning.multi_objectives.higher_is_better, [True])
+
+        test = '''
+        model:
+          name: inout_yaml 
+          framework: mxnet
+          inputs: x, y
+        tuning:
+          multi_objectives:
+            objective: accuracy, performance
+            higher_is_better: True, False
+        '''
+        helper(test)
+        config = conf.Conf('fake_conf.yaml')
+        self.assertEqual(config.usr_cfg.tuning.multi_objectives.higher_is_better, [True, False])
+
+        test = '''
+        model:
+          name: inout_yaml 
+          framework: mxnet
+          inputs: x, y
+        tuning:
+          multi_objectives:
+            objective: accuracy, performance
+            higher_is_better: True False
+        '''
+        helper(test)
+        config = conf.Conf('fake_conf.yaml')
+        self.assertEqual(config.usr_cfg.tuning.multi_objectives.higher_is_better, [True, False])
+
+        test = '''
+        model:
+          name: inout_yaml 
+          framework: mxnet
+          inputs: x, y
+        tuning:
+          multi_objectives:
+            objective: accuracy, performance
+            higher_is_better: [True, False]
+        '''
+        helper(test)
+        config = conf.Conf('fake_conf.yaml')
+        self.assertEqual(config.usr_cfg.tuning.multi_objectives.higher_is_better, [True, False])
+
+        test = '''
+        model:
+          name: inout_yaml 
+          framework: mxnet
+          inputs: x, y
+        tuning:
+          multi_objectives:
+            objective: accuracy, performance
+            higher_is_better: True False
+            weight: [0.2, 0.1, 0.7]
+        '''
+        helper(test)
+        self.assertRaises(RuntimeError, conf.Conf, 'fake_conf.yaml')
+
     def test_modelwise_conf_merge(self):
         test = '''
         model:
@@ -403,6 +463,52 @@ class TestConf(unittest.TestCase):
         tune_space = config.modelwise_tune_space(framework_modelwise_capability)
         self.assertEqual(tune_space['CONV2D']['activation']['algorithm'], ['minmax'])
 
+    def test_metric(self):
+        test = '''
+        model:
+          name: metric_yaml 
+          framework: mxnet
+        evaluation:
+          accuracy:
+            multi_metrics:
+              topk: 1
+              MSE: {}
+        '''
+        helper(test)
+
+        metrics = {'topk': 1, 'MSE': {}}
+        config = conf.Quantization_Conf('fake_conf.yaml')
+        self.assertEqual(config.usr_cfg.evaluation.accuracy.multi_metrics, metrics)
+
+        test = '''
+        model:
+          name: metric_yaml 
+          framework: mxnet
+        evaluation:
+          accuracy:
+            multi_metrics:
+              weight: 0.5 0.5 0.6
+              topk: 1
+              MSE: {}
+        '''
+        helper(test)
+        self.assertRaises((AssertionError, RuntimeError), conf.Conf, 'fake_conf.yaml')
+
+        test = '''
+        model:
+          name: metric_yaml 
+          framework: mxnet
+        evaluation:
+          accuracy:
+            multi_metrics:
+              higher_is_better: True, False
+              topk: 1
+              MSE: {}
+        '''
+        helper(test)
+        config = conf.Quantization_Conf('fake_conf.yaml')
+        self.assertEqual(config.usr_cfg.evaluation.accuracy.multi_metrics.higher_is_better, [True, False])
+
     def test_modelwise_conf_merge2(self):
         test = '''
         model:
@@ -624,7 +730,7 @@ class TestConf(unittest.TestCase):
                 dummy:
                   shape: [[224,224], [256,256]]
                   high: [128., 127]
-                  low: 1
+                  low: 1, 0
                   dtype: ['float32', 'int8']
         '''
         helper(test)
@@ -634,7 +740,7 @@ class TestConf(unittest.TestCase):
         self.assertTrue(isinstance(dataset['shape'], list))
         self.assertTrue(isinstance(dataset['high'][1], float))
         self.assertTrue(isinstance(dataset['high'][0], float))
-        self.assertTrue(isinstance(dataset['low'], float))
+        self.assertTrue(isinstance(dataset['low'][0], float))
 
         test = '''
         model:
@@ -723,7 +829,7 @@ class TestConf(unittest.TestCase):
               batch_size: 1
               dataset:
                 dummy:
-                  shape: [224,224]
+                  shape: 224,224
               transform:
                 BilinearImagenet:
                   height: 224
