@@ -24,8 +24,7 @@ def build_fake_yaml_footprint():
               topk: 1
           performance: {}
         tuning:
-          multi_objective:
-            objective: footprint
+          objective: footprint
           strategy:
             name: fake
           accuracy_criterion:
@@ -52,8 +51,7 @@ def build_fake_yaml_model_size():
               topk: 1
           performance: {}
         tuning:
-          multi_objective:
-            objective: modelsize
+          objective: modelsize
           strategy:
             name: fake
           accuracy_criterion:
@@ -288,8 +286,8 @@ class TestObjs(unittest.TestCase):
         conf.model.framework = 'onnxrt_integerops'
         conf.quantization.approach = 'post_training_dynamic_quant'
         conf.tuning.accuracy_criterion.absolute = 0.3
-        conf.tuning.multi_objective.objective = ['accuracy', 'performance']
-        conf.tuning.multi_objective.weight = [0.8, 0.2]
+        conf.tuning.multi_objectives.objective = ['accuracy', 'performance']
+        conf.tuning.multi_objectives.weight = [0.8, 0.2]
         conf.tuning.exit_policy.timeout = 10000
         conf.tuning.exit_policy.max_trials = 2
         quantize = Quantization(conf)
@@ -299,9 +297,11 @@ class TestObjs(unittest.TestCase):
 
     def test_tune_data(self):
         from neural_compressor.objective import MultiObjective
-        obj = MultiObjective(['accuracy', 'modelsize', 'performance'],
-                             {'relative': 0.1},
-                             [0.7, 0.2, 0.1])
+        obj = MultiObjective(
+            objectives=['accuracy', 'modelsize', 'performance'],
+            accuracy_criterion={'relative': 0.1},
+            obj_criterion=[True, False, False],
+            obj_weight=[0.7, 0.2, 0.1])
         baseline = [0.8, [0.8, 780, 0.6]]
         tune_data = [
             [0.760, [0.760, 400, 0.23]],
@@ -316,22 +316,8 @@ class TestObjs(unittest.TestCase):
         self.assertEqual(num, 4)
 
         obj = MultiObjective(['accuracy', 'modelsize', 'performance'],
-                             {'relative': 0.1})
-        baseline = [0.8, [0.8, 780, 0.6]]
-        tune_data = [
-            [0.760, [0.760, 400, 0.23]],
-            [0.778, [0.778, 420, 0.24]],
-            [0.750, [0.750, 430, 0.22]],
-            [0.720, [0.720, 410, 0.18]],
-            [0.790, [0.790, 360, 0.15]], 
-            [0.750, [0.750, 430, 0.24]],
-            [0.785, [0.785, 360, 0.13]]]
-
-        num, _ = obj.best_result(tune_data, baseline)
-        self.assertEqual(num, 6)
-
-        obj = MultiObjective(['accuracy', 'modelsize', 'performance'],
-                             {'absolute': 0.3})
+                             {'relative': 0.1},
+                             obj_criterion=[True, False, False])
         baseline = [0.8, [0.8, 780, 0.6]]
         tune_data = [
             [0.760, [0.760, 400, 0.23]],
@@ -347,7 +333,25 @@ class TestObjs(unittest.TestCase):
 
         obj = MultiObjective(['accuracy', 'modelsize', 'performance'],
                              {'absolute': 0.3},
-                             [0.6, 0.1, 0.3])
+                             obj_criterion=[True, False, False])
+        baseline = [0.8, [0.8, 780, 0.6]]
+        tune_data = [
+            [0.760, [0.760, 400, 0.23]],
+            [0.778, [0.778, 420, 0.24]],
+            [0.750, [0.750, 430, 0.22]],
+            [0.720, [0.720, 410, 0.18]],
+            [0.790, [0.790, 360, 0.15]], 
+            [0.750, [0.750, 430, 0.24]],
+            [0.785, [0.785, 360, 0.13]]]
+
+        num, _ = obj.best_result(tune_data, baseline)
+        self.assertEqual(num, 6)
+
+        obj = MultiObjective(
+            objectives=['accuracy', 'modelsize', 'performance'],
+            accuracy_criterion={'absolute': 0.3},
+            obj_criterion=[True, False, False],
+            obj_weight=[0.6, 0.1, 0.3])
         baseline = [0.8, [0.8, 780, 0.6]]
         tune_data = [
             [0.760, [0.760, 400, 0.23]],
@@ -362,7 +366,7 @@ class TestObjs(unittest.TestCase):
 
         obj = MultiObjective(['accuracy', 'modelsize', 'performance'],
                              {'absolute': 0.04, 'higher_is_better': False},
-                             [0.6, 0.1, 0.3])
+                             obj_weight=[0.6, 0.1, 0.3])
         baseline = [0.75, [0.75, 780, 0.6]]
         tune_data = [
             [0.760, [0.760, 400, 0.23]],
@@ -377,7 +381,7 @@ class TestObjs(unittest.TestCase):
 
         obj = MultiObjective(['accuracy', 'modelsize', 'performance'],
                              {'absolute': 0.4, 'higher_is_better': False},
-                             [0.6, 0.1, 0.3])
+                             obj_weight=[0.6, 0.1, 0.3])
         baseline = [0.0, [0.0, 780, 0.6]]
         tune_data = [
             [0.00, [0.00, 400, 0.23]],
@@ -392,7 +396,8 @@ class TestObjs(unittest.TestCase):
  
         obj = MultiObjective(['modelsize', 'performance'],
                              {'relative': 0.08},
-                             [0.2, 0.8])
+                             obj_criterion=[False],
+                             obj_weight=[0.2, 0.8])
         baseline = [0.8, [780, 0.6]]
         tune_data = [
             [0.760, [400, 0.23]],
@@ -406,5 +411,145 @@ class TestObjs(unittest.TestCase):
         num, _ = obj.best_result(tune_data, baseline)
         self.assertEqual(num, 6)
 
+    def test_multi_obj_metric(self):
+        from neural_compressor.objective import MultiObjective
+        obj = MultiObjective(['accuracy', 'modelsize', 'performance'],
+                             {'relative': 0.04, 'higher_is_better': True},
+                             metric_criterion=[True, True],
+                             metric_weight=[0., 1.],
+                             obj_criterion=[True, False, False],
+                             obj_weight=[0.6, 0.1, 0.3])
+        baseline = [[0.75, 0.4], [[0.75, 0.4], 780, 0.6]]
+        tune_data = [
+            [[0.760, 0.4], [[0.760, 0.4], 400, 0.23]],
+            [[0.778, 0.3], [[0.778, 0.3], 400, 0.10]],
+            [[0.750, 0.3], [[0.750, 0.3], 400, 0.22]],
+            [[0.720, 0.3], [[0.720, 0.3], 400, 0.18]],
+            [[0.790, 0.3], [[0.790, 0.3], 400, 0.15]], 
+            [[0.750, 0.3], [[0.750, 0.3], 400, 0.24]],
+            [[0.785, 0.3], [[0.785, 0.3], 400, 0.13]]]
+        num, _ = obj.best_result(tune_data, baseline)
+        self.assertEqual(num, 0)
+
+        obj = MultiObjective(['accuracy', 'modelsize', 'performance'],
+                             {'absolute': 0.4, 'higher_is_better': False},
+                             metric_criterion=[False, True],
+                             obj_weight=[0.6, 0.1, 0.3])
+        baseline = [[0.0, 0.9], [[0.0, 0.9], 780, 0.6]]
+        tune_data = [
+            [[0.00, 0.9], [[0.00, 0.9], 400, 0.23]],
+            [[0.80, 0.8], [[0.80, 0.8], 400, 0.10]],
+            [[0.02, 0.7], [[0.02, 0.7], 400, 0.22]],
+            [[0.10, 0.6], [[0.10, 0.6], 400, 0.18]],
+            [[0.20, 0.7], [[0.20, 0.7], 400, 0.15]], 
+            [[0.00, 0.7], [[0.00, 0.7], 400, 0.24]],
+            [[0.50, 0.7], [[0.50, 0.7], 400, 0.13]]]
+        num, _ = obj.best_result(tune_data, baseline)
+        self.assertEqual(num, 0)
+ 
+        obj = MultiObjective(['modelsize', 'performance'],
+                             {'relative': 0.08},
+                             metric_criterion=[True, True],
+                             metric_weight=[0.5,0.5],
+                             obj_weight=[0.2, 0.8])
+        baseline = [[0.8, 0.1], [780, 0.6]]
+        tune_data = [
+            [[0.760, 0.093], [400, 0.23]],
+            [[0.778, 0.094], [420, 0.24]],
+            [[0.750, 0.092], [430, 0.22]],
+            [[0.720, 0.093], [410, 0.18]],
+            [[0.790, 0.093], [360, 0.15]], 
+            [[0.750, 0.093], [430, 0.24]],
+            [[0.785, 0.060], [360, 0.13]]]
+
+        num, _ = obj.best_result(tune_data, baseline)
+        self.assertEqual(num, 6)
+
+        obj = MultiObjective(['modelsize', 'performance'],
+                             {'absolute': 0.013},
+                             metric_criterion=[True, True],
+                             metric_weight=[0.5,0.5],
+                             obj_weight=[0.2, 0.8])
+        baseline = [[0.8, 0.1], [780, 0.6]]
+        tune_data = [
+            [[0.760, 0.093], [400, 0.23]],
+            [[0.778, 0.094], [420, 0.24]],
+            [[0.750, 0.092], [430, 0.22]],
+            [[0.720, 0.093], [410, 0.18]],
+            [[0.790, 0.093], [360, 0.15]], 
+            [[0.750, 0.093], [430, 0.24]],
+            [[0.785, 0.060], [360, 0.13]]]
+
+        num, _ = obj.best_result(tune_data, baseline)
+        self.assertEqual(num, 4)
+
+        obj = MultiObjective(['modelsize', 'performance'],
+                             {'relative': 0.08},
+                             metric_criterion=[True, True],
+                             obj_weight=[0.2, 0.8])
+        baseline = [[0.8, 0.1], [780, 0.6]]
+        tune_data = [
+            [[0.760, 0.093], [400, 0.23]],
+            [[0.778, 0.094], [420, 0.24]],
+            [[0.750, 0.092], [430, 0.22]],
+            [[0.720, 0.093], [410, 0.18]],
+            [[0.790, 0.093], [360, 0.15]], 
+            [[0.750, 0.093], [430, 0.24]],
+            [[0.785, 0.060], [360, 0.13]]]
+
+        num, _ = obj.best_result(tune_data, baseline)
+        self.assertEqual(num, 4)
+
+        obj = MultiObjective(['modelsize', 'performance'],
+                             {'absolute': 0.06},
+                             metric_criterion=[True, True],
+                             obj_weight=[0.2, 0.8])
+        baseline = [[0.8, 0.1], [780, 0.6]]
+        tune_data = [
+            [[0.760, 0.093], [400, 0.23]],
+            [[0.778, 0.094], [420, 0.24]],
+            [[0.750, 0.092], [430, 0.22]],
+            [[0.720, 0.093], [410, 0.18]],
+            [[0.790, 0.093], [360, 0.15]], 
+            [[0.750, 0.093], [430, 0.24]],
+            [[0.785, 0.060], [360, 0.13]]]
+
+        num, _ = obj.best_result(tune_data, baseline)
+        self.assertEqual(num, 6)
+
+        obj = MultiObjective(['modelsize', 'performance'],
+                             {'relative': 0.08},
+                             metric_criterion=[True, False],
+                             obj_weight=[0.2, 0.8])
+        baseline = [[0.8, 0.1], [780, 0.6]]
+        tune_data = [
+            [[0.760, 0.093], [400, 0.23]],
+            [[0.778, 0.094], [420, 0.24]],
+            [[0.750, 0.092], [430, 0.22]],
+            [[0.720, 0.093], [410, 0.18]],
+            [[0.790, 0.093], [360, 0.15]], 
+            [[0.750, 0.093], [430, 0.24]],
+            [[0.785, 0.060], [360, 0.13]]]
+
+        num, _ = obj.best_result(tune_data, baseline)
+        self.assertEqual(num, 6)
+
+        obj = MultiObjective(['modelsize', 'performance'],
+                             {'absolute': 0.07},
+                             metric_criterion=[True, False],
+                             obj_weight=[0.2, 0.8])
+        baseline = [[0.8, 0.1], [780, 0.6]]
+        tune_data = [
+            [[0.760, 0.093], [400, 0.23]],
+            [[0.778, 0.094], [420, 0.24]],
+            [[0.750, 0.092], [430, 0.22]],
+            [[0.720, 0.093], [410, 0.18]],
+            [[0.790, 0.093], [360, 0.15]], 
+            [[0.750, 0.093], [430, 0.24]],
+            [[0.785, 0.060], [360, 0.13]]]
+
+        num, _ = obj.best_result(tune_data, baseline)
+        self.assertEqual(num, 6)
+
 if __name__ == "__main__":
     unittest.main()
