@@ -6,6 +6,7 @@ import yaml
 import tensorflow as tf
 import importlib
 import shutil
+from tensorflow.python.framework import graph_util
 
 def build_fake_yaml():
     fake_yaml = '''
@@ -135,6 +136,28 @@ def build_fake_yaml5():
         yaml.dump(y,f)
     f.close()
 
+def build_fake_yaml6():
+    fake_yaml = '''
+        model:
+          name: fake_yaml
+          framework: tensorflow
+          inputs: x
+          outputs: op_to_store
+        device: cpu
+        tuning:
+          strategy:
+            name: fake
+          accuracy_criterion:
+            relative: 0.01
+          workspace:
+            path: saved
+        '''
+    y = yaml.load(fake_yaml, Loader=yaml.SafeLoader)
+    with open('fake_yaml6.yaml',"w",encoding="utf-8") as f:
+        yaml.dump(y,f)
+    f.close()
+
+
 def build_fake_model():
     try:
         graph = tf.Graph()
@@ -208,6 +231,16 @@ def build_fake_strategy():
         f.writelines(seq)
     f.close()
 
+class Metric:
+    def update(self, predict, label):
+        pass
+
+    def reset(self):
+        pass
+
+    def result(self):
+        return 0.5
+
 class TestQuantization(unittest.TestCase):
     @classmethod
     def setUpClass(self):
@@ -217,6 +250,7 @@ class TestQuantization(unittest.TestCase):
         build_fake_yaml3()
         build_fake_yaml4()
         build_fake_yaml5()
+        build_fake_yaml6()
         build_fake_strategy()
 
     @classmethod
@@ -226,31 +260,48 @@ class TestQuantization(unittest.TestCase):
         os.remove('fake_yaml3.yaml')
         os.remove('fake_yaml4.yaml')
         os.remove('fake_yaml5.yaml')
+        os.remove('fake_yaml6.yaml')
         os.remove(os.path.join(os.path.dirname(importlib.util.find_spec('neural_compressor').origin), 'strategy/fake.py'))
         shutil.rmtree('./saved', ignore_errors=True)
 
-    def test_autosave(self):
-        from neural_compressor.experimental import Quantization, common
-        quantizer = Quantization('fake_yaml.yaml')
-        dataset = quantizer.dataset('dummy', shape=(100, 3, 3, 1), label=True)
-        quantizer.eval_dataloader = common.DataLoader(dataset)
-        quantizer.calib_dataloader = common.DataLoader(dataset)
-        quantizer.model = self.constant_graph
-        output_graph = quantizer.fit()
-
     def test_resume(self):
-        from neural_compressor.experimental import Quantization, common
-        quantizer = Quantization('fake_yaml5.yaml')
-        dataset = quantizer.dataset('dummy', shape=(100, 3, 3, 1), label=True)
-        quantizer.eval_dataloader = common.DataLoader(dataset)
-        quantizer.calib_dataloader = common.DataLoader(dataset)
-        quantizer.model = self.constant_graph
-        output_graph = quantizer.fit()
-        quantizer = Quantization('fake_yaml2.yaml')
-        quantizer.eval_dataloader = common.DataLoader(dataset)
-        quantizer.calib_dataloader = common.DataLoader(dataset)
-        quantizer.model = self.constant_graph
-        output_graph = quantizer.fit()
+        tf.compat.v1.disable_eager_execution()
+        tf.compat.v1.reset_default_graph()
+        tf.compat.v1.set_random_seed(1)
+        x = tf.compat.v1.placeholder(tf.float32, [1, 32, 32, 3], name="x")
+        top_relu = tf.nn.relu(x)
+        paddings = tf.constant([[0, 0], [1, 1], [1, 1], [0, 0]])
+        x_pad = tf.pad(top_relu, paddings, "CONSTANT")
+        conv_weights = tf.compat.v1.get_variable("weight", [3, 3, 3, 3],
+                                                 initializer=tf.compat.v1.random_normal_initializer())
+        conv = tf.nn.conv2d(x_pad, conv_weights, strides=[1, 2, 2, 1], padding="VALID")
+        relu = tf.nn.relu(conv)
+
+        relu6 = tf.nn.relu6(relu, name='op_to_store')
+
+        out_name = relu6.name.split(':')[0]
+        with tf.compat.v1.Session() as sess:
+            sess.run(tf.compat.v1.global_variables_initializer())
+            output_graph_def = graph_util.convert_variables_to_constants(
+                sess=sess,
+                input_graph_def=sess.graph_def,
+                output_node_names=[out_name])
+
+            from neural_compressor.experimental import Quantization, common
+            quantizer = Quantization('fake_yaml5.yaml')
+            dataset = quantizer.dataset('dummy', shape=(100, 32, 32, 3), label=True)
+            quantizer.eval_dataloader = common.DataLoader(dataset)
+            quantizer.calib_dataloader = common.DataLoader(dataset)
+            quantizer.model = output_graph_def
+            output_graph = quantizer.fit()
+            self.assertNotEqual(output_graph, None)
+            self.assertTrue(os.path.exists("./saved"))
+            quantizer = Quantization('fake_yaml2.yaml')
+            quantizer.eval_dataloader = common.DataLoader(dataset)
+            quantizer.calib_dataloader = common.DataLoader(dataset)
+            quantizer.model = output_graph_def
+            output_graph = quantizer.fit()
+            # self.assertNotEqual(output_graph, None) # disable this check, the code has bug of recover from resume
 
     def test_autodump(self):
         # test auto_dump using old api
@@ -261,6 +312,7 @@ class TestQuantization(unittest.TestCase):
         quantizer.model = self.constant_graph
         output_graph = quantizer(self.constant_graph, \
                                  q_dataloader=dataloader, eval_dataloader=dataloader)
+        self.assertNotEqual(output_graph, None)
 
     def test_performance_only(self):
         from neural_compressor.experimental import Quantization, common
@@ -270,6 +322,7 @@ class TestQuantization(unittest.TestCase):
         quantizer.calib_dataloader = common.DataLoader(dataset)
         quantizer.model = self.constant_graph
         output_graph = quantizer.fit()
+        self.assertNotEqual(output_graph, None)
 
     def test_fit_method(self):
         from neural_compressor.experimental import Quantization, common
@@ -279,6 +332,7 @@ class TestQuantization(unittest.TestCase):
         quantizer.calib_dataloader = common.DataLoader(dataset)
         quantizer.model = self.constant_graph
         output_graph = quantizer.fit()
+        self.assertNotEqual(output_graph, None)
 
     def test_quantization_without_yaml(self):
         from neural_compressor.experimental import Quantization, common
@@ -288,6 +342,7 @@ class TestQuantization(unittest.TestCase):
         quantizer.eval_dataloader = common.DataLoader(dataset)
         quantizer.calib_dataloader = common.DataLoader(dataset)
         output_graph = quantizer.fit()
+        self.assertNotEqual(output_graph, None)
 
     def test_invalid_eval_func(self):
         from neural_compressor.experimental import Quantization, common
@@ -297,9 +352,78 @@ class TestQuantization(unittest.TestCase):
         quantizer.calib_dataloader = common.DataLoader(dataset)
         quantizer.model = self.constant_graph
         def invalid_eval_func(model):
-          return [1.]
+            return [[1.]]
         quantizer.eval_func = invalid_eval_func
         output_graph = quantizer.fit()
+        self.assertEqual(output_graph, None)
 
+        def invalid_eval_func(model):
+            return '0.1'
+        quantizer.eval_func = invalid_eval_func
+        output_graph = quantizer.fit()
+        self.assertEqual(output_graph, None)
+
+
+    def test_custom_metric(self):
+        from neural_compressor.experimental import Quantization, common
+        quantizer = Quantization('fake_yaml6.yaml')
+        dataset = quantizer.dataset('dummy', shape=(100, 3, 3, 1), label=True)
+        quantizer.eval_dataloader = common.DataLoader(dataset)
+        quantizer.calib_dataloader = common.DataLoader(dataset)
+        quantizer.model = self.constant_graph
+        quantizer.metric = Metric()
+        quantizer.fit()
+        self.assertEqual(quantizer.strategy.evaluation_result[0], 0.5)
+
+    def test_custom_objective(self):
+        from neural_compressor.experimental import Quantization, common
+        from neural_compressor.objective import Objective, objective_registry
+        import tracemalloc
+        class MyObjective(Objective):
+          representation = 'MyObj'
+          def __init__(self):
+              super().__init__()
+          def start(self):
+              tracemalloc.start()
+          def end(self):
+              _, peak = tracemalloc.get_traced_memory()
+              tracemalloc.stop()
+              self._result_list.append(peak // 1048576)
+        quantizer = Quantization('fake_yaml.yaml')
+        dataset = quantizer.dataset('dummy', shape=(100, 3, 3, 1), label=True)
+        quantizer.eval_dataloader = common.DataLoader(dataset)
+        quantizer.calib_dataloader = common.DataLoader(dataset)
+        quantizer.model = self.constant_graph
+        quantizer.objective = MyObjective()
+        output_graph = quantizer.fit()
+        self.assertNotEqual(output_graph, None)
+
+        class MyObjective(Objective):
+          representation = 'Accuracy'
+          def __init__(self):
+              super().__init__()
+          def start(self):
+              tracemalloc.start()
+          def end(self):
+              _, peak = tracemalloc.get_traced_memory()
+              tracemalloc.stop()
+              self._result_list.append(peak // 1048576)
+        quantizer = Quantization()
+        with self.assertRaises(ValueError):
+            quantizer.objective = MyObjective()
+
+        with self.assertRaises(ValueError):
+            @objective_registry
+            class MyObjective(Objective):
+              representation = 'Accuracy'
+              def __init__(self):
+                  super().__init__()
+              def start(self):
+                  tracemalloc.start()
+              def end(self):
+                  _, peak = tracemalloc.get_traced_memory()
+                  tracemalloc.stop()
+                  self._result_list.append(peak // 1048576)
+ 
 if __name__ == "__main__":
     unittest.main()
