@@ -41,6 +41,7 @@ from neural_compressor.ux.utils.utils import (
     load_help_nc_params,
     load_model_config,
     load_transforms_config,
+    normalize_string,
     parse_to_string_list,
     release_tag,
     verify_file_path,
@@ -210,6 +211,15 @@ class TestUtils(unittest.TestCase):
             expected_filename="image_recognition.yaml",
         )
 
+    def test_get_predefined_onnx_object_detection_config_path(self) -> None:
+        """Test getting predefined config path for onnx object detection models."""
+        self._assert_predefined_config_path(
+            framework=Frameworks.ONNX.value,
+            domain=Domains.OBJECT_DETECTION.value,
+            domain_flavour=DomainFlavours.NONE.value,
+            expected_filename="object_detection.yaml",
+        )
+
     def test_get_predefined_onnx_nlp_config_path(self) -> None:
         """Test getting predefined config path for onnx NLP models."""
         self._assert_predefined_config_path(
@@ -232,7 +242,7 @@ class TestUtils(unittest.TestCase):
         with self.assertRaises(Exception):
             get_predefined_config_path(
                 framework=Frameworks.ONNX.value,
-                domain="object_detection",
+                domain="recommendation",
             )
 
     def test_check_module(self) -> None:
@@ -632,9 +642,6 @@ class TestUtils(unittest.TestCase):
 
         actual = get_metrics_dict()
 
-        print("\n\nactual")
-        print(actual)
-
         mocked_load_help_nc_params.assert_called_once_with("metrics")
         self.assertEqual(expected, actual)
 
@@ -662,6 +669,12 @@ class TestUtils(unittest.TestCase):
         result = parse_to_string_list(nodes)
         self.assertEqual(result, ["input_1", "input_2"])
 
+    def test_normalize_string(self) -> None:
+        """Test string normalization."""
+        string = "/Some string with extra / characters: éèà'çëöāãñę"
+        result = normalize_string(string)
+        self.assertEqual(result, "some_string_with_extra_characters_eeaceoaane")
+
 
 if __name__ == "__main__":
     unittest.main()
